<?php

/**
 * バージョン
 */
define('MAILFORMPHP_VERSION', '1.0.0');

// PHPのバージョン取得
$version = explode('.', phpversion());
if(is_array($version)){
	if (!defined('PHP_MAJOR_VERSION')) {
		define('PHP_MAJOR_VERSION',   $version[0]);
	}
	if (!defined('PHP_MINOR_VERSION')) {
		define('PHP_MINOR_VERSION',   $version[1]);
	}
	if (!defined('PHP_RELEASE_VERSION')) {
		define('PHP_RELEASE_VERSION', $version[2]);
	}
}

/*
 * 5.2.1以上なら-msが使えるのでバージョンから判別
 * http://www.asahi-net.or.jp/~wv7y-kmr/memo/php_mbstring.html#encoding_list
 */
function get_iso2022jp(){
	if (PHP_MAJOR_VERSION>=5&&PHP_MINOR_VERSION>=2&&PHP_RELEASE_VERSION>=1) {
		// 5.2.1以上なら
		return 'iso-2022-jp-ms';
	}
	return 'iso-2022-jp';
}

/*
 * PHPの動作モード取得
 */
function getSapiType(){
	if (substr(php_sapi_name(), 0, 3) == 'cgi') {
		return '「CGI版のPHP」を使用している可能性が高いです';
	} else {
		return '「モジュール版のPHP」を使用している可能性が高いです';
	}
}

/**
 * $_POST,$_GETのget_magic_quotes_gpcへの対応
 *
 * @param	$_POST | $_GET
 * @return	処理済みの配列
 */
function post_filter($arr) {
	if (!is_array($arr)) {
		return $arr;
	}

	if (get_magic_quotes_gpc()) {
		foreach ($arr as $k => $v) {
			$a[$k] = is_array($v) ? post_filter($v) : stripslashes($v);
		}
	} else {
		foreach ($arr as $k => $v) {
			$a[$k] = is_array($v) ? post_filter($v) : stripslashes(addslashes($v));
		}
	}
	return $a;
}

/**
 * 配列内の全ての値をエンコード（再帰）
 *
 * @param	変換したい配列
 * @param	変換後のエンコード
 * @param	変換前のエンコード
 * @return	変換後の配列、または変数
 */
function encode_filter($str, $to_encoding, $from_encoding) {
	if (is_array($str)) {
		foreach ($str as $key => $value) {
			$str[$key] = encode_filter($value, $to_encoding, $from_encoding);
		}
	} else {
		$str = mb_convert_encoding($str, $to_encoding, $from_encoding);
	}
	return $str;
}

/**
 * コピーライト
 */
function copyright(){
	$c=___();
	if (MAILFORMPHP_OUTPUT_ENCODE !== MAILFORMPHP_DEFAULT_ENCODE) {
		$c = mb_convert_encoding($c, MAILFORMPHP_OUTPUT_ENCODE, MAILFORMPHP_DEFAULT_ENCODE);
	}
	echo $c;
}

/**
 * 文字コード設定
 *
 * @param	ユーザー設定ファイル内の文字コード指定
 * @return	設定するエンコード名
 */
function mojicodeDetection($detectmode=1) {
	switch ($detectmode) {
		case '2': $enc = 'SJIS-win'; // not Shift_JIS
			break;
		case '3': $enc = 'eucJP-win'; // not EUC-JP
			break;
		case '1':
		default : $enc = 'UTF-8';
			break;
	}
	return $enc;
}

/**
 * テンプレートプリフィックス設定
 *
 * @param	ユーザー設定ファイル内のテンプレートタイプ指定
 * @return	設定するプリフィックス
 * @return	設定するユーザータイプ
 */
function userAgentDetection($detectmode=1) {
	$agent = $_SERVER['HTTP_USER_AGENT'];

	// スマートフォン判別用正規表現パターン生成
	$smartphone_useragents = array(
		'iPhone', // Apple iPhone
		'iPod', // Apple iPod touch
		'Android', // 1.5+ Android
		'dream', // Pre 1.5 Android
		'CUPCAKE', // 1.5+ Android
		'blackberry9500', // Storm
		'blackberry9530', // Storm
		'blackberry9520', // Storm v2
		'blackberry9550', // Storm v2
		'blackberry9800', // Torch
		'webOS', // Palm Pre Experimental
		'incognito', // Other iPhone browser
		'webmate'   // Other iPhone browser
	);
	foreach ($smartphone_useragents as $k => $v) {
		$smartphone_useragents[$k] = preg_quote($v);
	}
	$smartphone_pattern = '/(' . implode('|', $smartphone_useragents) . ')/i';

	// 携帯判別用正規表現パターン生成
	$ketai_useragents = array(
		// docomo
		'DoCoMo',
		// SoftBank
		'SoftBank',
		'Vodafone',
		'J-PHONE',
		'MOT-',
		// AU
		'UP.Browser',
		'KDDI',
		// WILLCOM
		'WILLCOM',
		'DDIPOCKET',
		// EMOBILE
		'emobile',
	);
	foreach ($ketai_useragents as $k => $v) {
		$ketai_useragents[$k] = preg_quote($v);
	}
	$ketai_pattern = '/^(' . implode('|', $ketai_useragents) . ')/i';

	// スマートフォン用
	if (preg_match($smartphone_pattern, $agent, $match)) {
		$usertype = $match['0'];
		$prefix = 's';
	}

	// 携帯用
	else if (preg_match($ketai_pattern, $agent, $match)) {
		$hitkey = array_search($match['0'], $ketai_useragents);
		switch (true) {
			case $hitkey === '0' :
				$usertype = 'docomo';
				break;
			case ( '1' <= $hitkey && $hitkey <= '4' ) :
				$usertype = 'SoftBank';
				break;
			case ( '5' <= $hitkey && $hitkey <= '6' ) :
				$usertype = 'au';
				break;
			case ( '7' <= $hitkey && $hitkey <= '8' ) :
				$usertype = 'WILLCOM';
				break;
			case $hitkey === '9' :
				$usertype = 'EMOBILE';
				break;
		}
		$prefix = 'k';
	}

	// PC用
	else {
		$usertype = 'pc';
		$prefix = 'p';
	}

	// $prefix上書き
	switch ($detectmode) {
		case '2': $prefix = 'p';
			break;
		case '3': $prefix = 'k';
			break;
		case '4': $prefix = 's';
			break;
	}

	return array(
		$prefix,
		$usertype
	);
}

/**
 * パーミッション取得
 *
 * @param	パーミッションを取得するパス
 * @return	パーミッション（例：0755）
 */
function getPermission($path) {
	return substr(sprintf("%o", fileperms($path)), -4);
}

/**
 * ファイル（生成＋）書き込み
 *
 * @param	書き込むファイルのパス
 * @param	ファイルに書き込む内容
 * @param	モード（http://jp.php.net/manual/ja/function.fopen.php）
 * @return	成功: バイト数
 * 			失敗: false
 */
function makefile($path, $data, $mode='w') {
	$fp = fopen($path, $mode);
	if (!$fp) {
		return false;
	}
	flock($fp, LOCK_EX);
	$byte = fwrite($fp, $data);
	fclose($fp);
	return $byte;
}

/**
 * http_build_query (for PHP4)
 * http://jp2.php.net/manual/ja/function.http-build-query.php
 */
if (!function_exists('http_build_query')) {

	function http_build_query($data, $prefix='', $sep='', $key='') {
		$ret = array();
		foreach ((array) $data as $k => $v) {
			if (is_int($k) && $prefix != null) {
				$k = urlencode($prefix . $k);
			}
			if ((!empty($key)) || ($key === 0)) {
				$k = $key . '[' . urlencode($k) . ']';
			}
			if (is_array($v) || is_object($v)) {
				array_push($ret, http_build_query($v, '', $sep, $k));
			} else {
				array_push($ret, $k . '=' . urlencode($v));
			}
		}
		if (empty($sep)) {
			$sep = ini_get('arg_separator.output');
		}
		return implode($sep, $ret);
	}

}

if (!function_exists('str_split')) {

	function str_split($string, $split_length=1) {
		$a = array();
		$l = strlen($string);
		for($i=0;$i<$l;$i+=$split_length){
			$a[] = substr($string,$i,$split_length);
		}
		return $a;
	}
}

// bcmath未インストール対応
if (!function_exists('bcpow')) {
	function bcpow($left_operand, $right_operand, $scale=0) {
		if ($right_operand==0) return '1';
		for($r=0;$r<$right_operand;$r++) {
			$left_operand *= $left_operand;
		}
		return $left_operand;
	}
}

if (!function_exists('json_decode')) {
	function json_decode($data)	{
		require_once('JSON.php');
		$json = new Services_JSON();
		return $json->decode($data);
	}
}

function makepw($length=8){
	$chars = <<< CHARS
!"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_`abcdefghijklmnopqrstuvwxyz{|}~
CHARS;
	$chars = str_split(trim($chars));
	shuffle($chars);
	$charsCount = count($chars);
	for( $i=0; $i<$length; $i++ ){
		$password .= $chars[ mt_rand(0, $charsCount - 1) ];
	}
	return $password ;
}

/*
 * 設定ファイル用定義作成
 *
 * @param 定義名
 * @param 定義値
 */
function addDefine($name, $value){
	$name = trim($name);
	if($name=='') return '';
	$value = addslashes($value);
	switch(true){
		case is_numeric($value):
			break;
		default:
			$value = "'" . $value . "'" ;
			break;
	}
//	return "define('".$name."',".$value.");";
	return '$'.$name.' = '.$value.';';
}

/*
 * 設定ファイル用配列値作成
 *
 * @param 定義名
 * @param 定義値
 */
function addArraysValue($name, $value){
	$name = trim($name);
	if($name=='') return '';
	$value = addslashes($value);
	switch(true){
		case is_numeric($value):
			break;
		default:
			$value = "'" . $value . "'" ;
			break;
	}
//	return "define('".$name."',".$value.");";
	return "'".$name."' => ".$value.',';
}

function encodeSize( $bytes ){
	$types = array(
		'B' , // バイト
		'KB', // キロバイト
		'MB', // メガバイト
		'GB', // ギガバイト
		'TB', // テラバイト
		'PB', // ペタバイト
		'EB', // エクサバイト
		'ZB', // ゼタバイト
		'YB', // ヨタバイト
	) ;
	list( $byte, $type ) = explode( " ", trim($bytes) );
	$key = array_search( $type, $types ) ;
	if( !is_numeric( $byte ) || $key === false ){
		return $bytes ;
	}
	return $byte * bcpow(1024,$key);
}

/**
 * PHP5.2.1未満用 一部機種依存文字対応クラス
 */
class dependentCode{

	/**
	 * リスト
	 * ex)
	 * array(
	 *	"\xE2\x85\xA0" => 'I',
	 * );
	 *
	 * @return array()
	 */
	function getList(){
		return array(
			"\xE2\x85\xA0" => 'I',
			"\xE2\x85\xA1" => 'II',
			"\xE2\x85\xA2" => 'III',
			"\xE2\x85\xA3" => 'IV',
			"\xE2\x85\xA4" => 'V',
			"\xE2\x85\xA5" => 'VI',
			"\xE2\x85\xA6" => 'VII',
			"\xE2\x85\xA7" => 'VIII',
			"\xE2\x85\xA8" => 'IX',
			"\xE2\x85\xA9" => 'X',
			"\xE2\x85\xB0" => 'i',
			"\xE2\x85\xB1" => 'ii',
			"\xE2\x85\xB2" => 'iii',
			"\xE2\x85\xB3" => 'iv',
			"\xE2\x85\xB4" => 'v',
			"\xE2\x85\xB5" => 'vi',
			"\xE2\x85\xB6" => 'vii',
			"\xE2\x85\xB7" => 'viii',
			"\xE2\x85\xB8" => 'ix',
			"\xE2\x85\xB9" => 'x',
			"\xE2\x91\xA0" => '(1)',
			"\xE2\x91\xA1" => '(2)',
			"\xE2\x91\xA2" => '(3)',
			"\xE2\x91\xA3" => '(4)',
			"\xE2\x91\xA4" => '(5)',
			"\xE2\x91\xA5" => '(6)',
			"\xE2\x91\xA6" => '(7)',
			"\xE2\x91\xA7" => '(8)',
			"\xE2\x91\xA8" => '(9)',
			"\xE2\x91\xA9" => '(10)',
			"\xE2\x91\xAA" => '(11)',
			"\xE2\x91\xAB" => '(12)',
			"\xE2\x91\xAC" => '(13)',
			"\xE2\x91\xAD" => '(14)',
			"\xE2\x91\xAE" => '(15)',
			"\xE2\x91\xAF" => '(16)',
			"\xE2\x91\xB0" => '(17)',
			"\xE2\x91\xB1" => '(18)',
			"\xE2\x91\xB2" => '(19)',
			"\xE2\x91\xB3" => '(20)',
			"\xE3\x8A\xA4" => '(上)',
			"\xE3\x8A\xA5" => '(中)',
			"\xE3\x8A\xA6" => '(下)',
			"\xE3\x8A\xA7" => '(左)',
			"\xE3\x8A\xA8" => '(右)',
			"\xE3\x8D\x89" => 'ミリ',
			"\xE3\x8D\x8D" => 'メートル',
			"\xE3\x8C\x94" => 'キロ',
			"\xE3\x8C\x98" => 'グラム',
			"\xE3\x8C\xA7" => 'トン',
			"\xE3\x8C\xA6" => 'ドル',
			"\xE3\x8D\x91" => 'リットル',
			"\xE3\x8C\xAB" => 'パーセント',
			"\xE3\x8C\xA2" => 'センチ',
			"\xE3\x8E\x9D" => 'cm',
			"\xE3\x8E\x8F" => 'kg',
			"\xE3\x8E\xA1" => 'm2',
			"\xE3\x8F\x8D" => 'K.K.',
			"\xE2\x84\xA1" => 'TEL',
			"\xE2\x84\x96" => 'No.',
			"\xE3\x8D\xBB" => '平成',
			"\xE3\x8D\xBC" => '昭和',
			"\xE3\x8D\xBD" => '大正',
			"\xE3\x8D\xBE" => '明治',
			"\xE3\x88\xB1" => '(株)',
			"\xE3\x88\xB2" => '(有)',
			"\xE3\x88\xB9" => '(代)',
		);
	}

	/**
	 * 変換
	 *
	 * @param	変換したい文字列
	 */
	function replace( $str ){
		$arr = $this->getList();
		return str_replace( array_keys($arr), array_values($arr), $str);
	}
}

function global_alert(){
	$output = null ;
	$err = array();

	// システム設定のチェック
	require SYSTEM_CONFIG;
	if ($base_url=='') {
		$err['s'][]='「フォームのURL」を設定して下さい。';
	}
	if ($thanks_mail_from_mail=='') {
		$err['s'][]='「送信元のメールアドレス」を設定して下さい。';
	}
	if ($alert_mail_to1=='') {
		$err['s'][]='「送信先(A)」を設定して下さい。';
	}
	if ($thanks_mail_template_p=='') {
		$err['s'][]='「確認メール用（入力者宛て）」を設定して下さい。';
	}
	if ($alert_mail_template_p=='') {
		$err['s'][]='「通知メール用（管理者宛て）」を設定して下さい。';
	}

	// フォーム設定のチェック
	require FORM_CONFIG;
	if ($thanks_mail_use=='1') {
		$recipients_check = false;
		foreach ( $form_config as $key => $config ){
			if ($config['setname']=='mail1'||$config['setname']=='mail2') {
				if ($config['recipients']=='yes') {
					$recipients_check = true;
				}
			}
		}
		if (!$recipients_check) {
			$err['f'][]='「確認メール」を利用する場合はフォーム設定内の「確認メールの送信先として使用する」に必ず１つチェックを入れて下さい。';
		}
	}



	if( count($err['s']) > 0 || count($err['f']) > 0 || DEMO_MODE ) {
		if( DEMO_MODE ) {
			$msg[] = 'この画面はデモです。実際にメールは送信されません。';
			$msg[] = '以下から管理画面の操作が確認できます。';
			$msg[] = '<a href="./admin.php" target="_blank">管理画面 &raquo;</a>　（メールアドレス：demo@kantaro-cgi.com　パスワード：kantaro）';
		} else {
			$msg[] = 'フォームの利用にはまだ設定がいくつか必要です。';

			if (count($err['s'])>0) {
				$msg[] = '■<b style="font-weight:bold">システム設定</b>';
				$msg[] = implode(PHP_EOL,$err['s']);
			}
			if (count($err['f'])>0) {
				$msg[] = '■<b style="font-weight:bold">フォーム設定</b>';
				$msg[] = implode(PHP_EOL,$err['f']);
			}
		}
		$output = '<div style="color:#FF0084;border:3px solid #FF0084;background:#FEE;font-size:14px;line-height:1.3;padding:5px;">'.implode(PHP_EOL,$msg).'</div>';

		if (MAILFORMPHP_DEFAULT_ENCODE !== MAILFORMPHP_OUTPUT_ENCODE) {
			$output = mb_convert_encoding($output, MAILFORMPHP_OUTPUT_ENCODE, MAILFORMPHP_DEFAULT_ENCODE);
		}

		if (MAILFORMPHP_PREFIX=='k') {
			// 携帯ならタグ変更
			$output = strip_tags($output);
			$output = '<hr color="red"><font color="red" size="3">'.$output.'</font><hr color="red">';
		}
	}

	echo nl2br($output);
}

function ___(){
	$__ ='_';
	$_="UG93ZXJlZCBieSA8YSBocmVmPSJodHRwOi8va2FudGFyby1jZ2kuY29tLyIgdGFyZ2V0PSJfYmxhbmsiIHRpdGxlPSLjg4fjgrbjgqTjg7Pjgqvjgrnjgr/jg6Doh6rnlLFDR0njgIzjgqvjg7Pjgr/jg63jg7xDR0njgI0iPuOCq+ODs+OCv+ODreODvENHSTwvYT4=";
	$lc=$s=null;
	return (crypt($lc,$s) == $lcc ? null : base64_decode($$__));
}
eval( 'function ge'.'tL'.'ice'.'ns'.'eCo'.'de() {$file="libs/LIC'.'ENS'.'E_CO'.'DE";return file_exists($file)?trim(@file_get_contents($file)):"";}' );
eval( 'function ch'.'eck'.'Co'.'de($s){if($s===""){return;}$s=explode("-",$s);$p=$c=$k=1;preg_match("/^(\d+)(\d{9})$/",$s[2],$m);list(,$q,$t)=$m;foreach(str_split($s[1])as$n){if($n>1){$c*=$n*$p;$c+=$q;$c=substr($c,0,9);}$k=substr(($k*=($n>1)?($n*$p):1),0,5);$p++;}$c*=$s[0];$c=substr($c,-9,9);return$c===$t&&$k==91597;}' );


/**
 * session class
 * */
class session {

	// セッションを保存するディレクトリ
	var $dir;
	// セッションキー
	var $key;
	// セッションの拡張子
	var $ext = 'cgi';
	// セッションファイルに記録されているデータ
	var $value = null;
	// セッションの有効時間
	var $expire = null;
	// メッセージ
	var $message;

	// コンストラクタ
	function session($sec=null) {
		// 有効時間設定
		$this->expire = time() - ( is_numeric($sec) ? $sec : 3600 );
	}

	// 変数の値を取得
	function getKey() {
		if (!isset($this->key)) {
			return null;
		}
		return $this->key;
	}

	// セッションファイルのパスを作成
	function getPath($key) {
		return $this->dir . DIRECTORY_SEPARATOR . ( $key ? $key : $this->key ) . '.' . $this->ext;
	}

	// セッションファイルの中身を変数として取得
	function getValue($key) {
		$path = $this->getPath($key);
		if (!file_exists($path)) {
			return null;
		}
		return file_get_contents($path);
	}

	// キー生成
	function makeKey() {
		return sha1(uniqid(mt_rand()));
	}

	// セッション処理開始
	function start() {
		if (!is_dir($this->dir)) {
			return false;
		}

		// テストファイルの生成・削除テスト
		$testfile = $this->dir . DIRECTORY_SEPARATOR . 'testfile.cgi';
		if (!makefile($testfile,time())) {
			die('Please check directory(' . $this->dir . ') Permission.');
		}
		unlink($testfile);

		// キーがあれば値をcheck()用に取得しておく
		if ($this->key !== null) {
			$this->value = $this->getValue($this->key);
			// 掃除より前に取得しておくことでタイムアウトの判定も
			// 行えるようにしておく
		}

		// セッションフォルダ掃除
		$files = glob($this->dir . DIRECTORY_SEPARATOR . '*.' . $this->ext);
		if ($files) {
			foreach ($files as $file) {
				if (file_exists($file) && filemtime($file) < $this->expire) {
					unlink($file);
				}
			}
		}
	}

	// セッションファイル作成
	function create($value='') {
		$recreate = true;
		$loop_limit = 10;
		$data = $value;
		while ($recreate) {
			$key = $this->makeKey();
			$path = $this->getPath($key);

			// ファイルが無ければ生成し、ループ終了
			if (!file_exists($path)) {
				makefile($path, $data);
				$recreate = false;
			}

			// $loop_limitが0以下になったら強制終了
			if (--$loop_limit <= 0) {
				$key = false;
				$recreate = false;
				$this->message = 'セッションの生成に失敗しました。' . PHP_EOL . '<a href="./">初めからやり直して下さい。</a>';
			}
		}

		$this->key = $key;
		return $key;
	}

	// セッション更新
	function update($value='') {
		$path = $this->getPath($this->key);
		if (!file_exists($path)) {
			$this->message = 'セッションがタイムアウトしました。' . PHP_EOL . '<a href="./">初めからやり直して下さい。</a>';
			return false;
		}
		$data = $value;
		makefile($path, $data);
		return $this->key;
	}

	// セッション確認
	function check($value='') {
		if ($value != '' && preg_match('/^' . $value . '$/', $this->value)) {
			return true;
		}
		$this->message = '不正なアクセスです。' . PHP_EOL . '<a href="./">初めからやり直して下さい。</a>';
		return false;
	}

	function message() {
		return $this->message;
	}

	function destroy() {
		$path = $this->getPath($this->key);
		if (file_exists($path)) {
			unlink($path);
		}
	}

}

class mailform {

	var $isXHTML;
	var $err = array();
	var $prefix = 'mf_';

	// 確認メール送信先
	var $recipients = '';
	var $replace_kind = array(
		'thanks_mail' => array(
			'mailform' => true,
			'date' => true,
			'number' => true,
			'ip' => true,
			'user_agent' => true,
		),
		'alert_mail' => array(
			'mailform' => true,
			'date' => true,
			'number' => true,
			'ip' => true,
			'user_agent' => true,
		),
		'pop_mail' => array(
			'mailform' => false,
			'date' => true,
			'number' => true,
			'ip' => true,
			'user_agent' => true,
		),
	);

	// 確認メール用{mailform}の中身
	var $thanks_value;
	// 通知メール用{mailform}の中身
	var $alert_value;
	// 問い合わせ番号
	var $number = null ;

	function setIndex($index) {
		$this->index = $index;
		$this->name = $this->prefix . 'name_' . $index;
		$this->conf = $this->setting[$index];
		// @todo XHTMLのスイッチ対応
		$this->isXHTML = false;
		$this->selected = ' selected' . ( $this->isXHTML ? '="selected"' : '' );
		$this->checked = ' checked' . ( $this->isXHTML ? '="checked"' : '' );
		$this->endtag = $this->isXHTML ? ' /' : '';
		$this->tag = array(
			'br' => '<br' . $this->endtag . '>',
		);

		/**
		 * 以下ファイルアップロードを
		 * スマホと携帯で非表示にするための処理
		 */

		if (MAILFORMPHP_PREFIX=='p') {
			// PCなら常にtrue
			return true;
		}

		// スマホ|携帯
		if (!preg_match('/^file/',$this->conf['setname'])) {
			return true;
		}

		return false;
	}

	function startSession(){
		$this->session = new session;
		$this->session->dir = MAILFORMPHP_SESSION_DIR;
		$this->session->key = $this->form[MAILFORMPHP_SESSION_NAME];
		return $this->session->start();
	}

	function getSession() {
		echo '<input type="hidden" name="' . MAILFORMPHP_SESSION_NAME . '" value="' . $this->session->getKey() . '"' . $this->endtag . '>';
	}

	function getSetting() {
		$this->setting_encode = 'utf-8';
		$form_config = array();
		require_once FORM_CONFIG;
		$this->select_value_split = "\\n";
		$this->length = count($form_config);
		foreach($form_config as $setting) {
			if($setting['select_values']){
				$setting['select_values'] = str_replace("\'","'",$setting['select_values']) ;
			}
			$this->setting[] = $setting ;
		}

		$jp = array(
			'name_shi' => '氏',
			'name_mei' => '名',
			'name_sei' => '姓',
			'name_kata_shi' => 'シ',
			'name_kata_mei' => 'メイ',
			'name_kata_sei' => 'セイ',
			'name_hira_shi' => 'し',
			'name_hira_mei' => 'めい',
			'name_hira_sei' => 'せい',
			'zip' => '郵便番号',
			'zip_search' => '郵便番号検索',
			'pref' => '都道府県',
			'city' => '市区町村',
			'addr' => '以下住所・番地',
			'bldg' => 'ビル・建物名等',
			'mail1' => 'メールアドレス',
			'mail2' => '確認の為、もう一度入力して下さい',
			'please_select' => '選択して下さい',
			'empty_input' => '<span class="empty">（未入力）</span>',
			'empty_select' => '<span class="empty">（未選択）</span>',
			'empty_upload' => '<span class="empty">（未登録）</span>',
			'list_marker' => '・',
			'kome' => '※',
			'zip_mark' => '〒',
			'uploaded_file' => '■アップロードされているファイル',
			'new_upload_file' => '■新しくアップロードされたファイル',
		);
		if (MAILFORMPHP_DEFAULT_ENCODE !== MAILFORMPHP_OUTPUT_ENCODE) {
			$this->jp = encode_filter($jp, MAILFORMPHP_OUTPUT_ENCODE, MAILFORMPHP_DEFAULT_ENCODE);
		} else {
			$this->jp = $jp;
		}

		return true;
	}

	function html($key, $start_tag='', $end_tag='') {
		if ($this->template_name == 'confirm') {
			return $this->conf[$key];
		} else {
			if ($this->conf[$key]) {
				echo $start_tag . nl2br($this->conf[$key]) . $end_tag;
			}
		}
	}

	function requiredMark($mark) {
		if (strpos($this->conf['required'], 'yes') !== false) {
			echo $mark;
		}
	}

	function error($start_tag='', $end_tag='') {
		if ($this->err[$this->name]) {
			echo $start_tag . nl2br($this->err[$this->name]) . $end_tag;
		}
	}

	function getMessage($start_tag='', $end_tag='') {
		echo $start_tag . nl2br($this->err['message']) . $end_tag;
	}

	function getNumber(){
		echo DEMO_MODE ? '0' : $this->form['number']; // デモモードの場合は問い合わせ番号を'0'で返す
	}

	/**
	* フォームのポストされた値に処理を施して出力
	*
	* @param	$form値
	* @param	オプション、カンマ区切りで複数指定可能
	* @return	処理済み文字列
	*/
	function convert($str, $options='', $is_echo=true) {
		// テキストとしての,処理用
		$comma = "[comma]";



	//	if (strpos($options, 'unescape') === false && strpos($options, 'escape') !== false) {
	//		$options = 'escape,' . $options;
	//	}

		// 標準でエスケープ
		// & → &amp;
		// < → &lt;
		// > → &gt;
		// " → &quot;
		// ' → &#39;
		$str = htmlspecialchars($str, ENT_QUOTES);

		if ($options !== '') {
			$options = str_replace('\,', $comma, $options);
			$options_arr = explode(',', $options);
			if (!is_array($options_arr)) continue;

			$option_values = array();
			foreach ($options_arr as $key => $option) {
				if ($option === '')	continue;
				$values = true ;
				if (strpos($option, '|') !== false) {
					list( $option, $value ) = explode('|', $option, 2);
					$values = explode('|', $value);
					if (is_array($values)) {
						foreach ($values as $key => $value) {
							$values[$key] = str_replace($comma, ',', $value);
						}
					}
				} else if (strpos($option, ':') !== false) {
					list( $option, $value ) = explode(':', $option, 2);
					$values = trim($value);
				}
				$option_values[$option] = $values ;
			}

			// comma
			if (array_key_exists('comma', $option_values)) {
				if (preg_match('/^[0-9]+$/',$str)) {
					$str = number_format($str);
				}
			}

			// replace
			if (array_key_exists('replace', $option_values)) {
				if (!is_array($str) && $str !== '') {
					$str = str_replace($option_values['replace']['0'], $option_values['replace']['1'], $str);
				}
			}

			// urlencode
			if (array_key_exists('urlencode', $option_values)) {
				if (!is_array($str) && $str !== '') {
					$str = urlencode($str);
				}
			}

			// urldecode
			if (array_key_exists('urldecode', $option_values)) {
				if (!is_array($str) && $str !== '') {
					$str = urldecode($str);
				}
			}

			// dec
			if (array_key_exists('dec', $option_values)) {
				if (preg_match('/^[0-9]+$/',$str)&&preg_match('/^[0-9]+$/',$option_values['dec'])) {
					$str = sprintf('%0' . $option_values['dec'] . 'd', $str);
				}
			}

			// date
			if (array_key_exists('date', $option_values)) {
				if (!is_array($str)) {
					$time = strtotime($str);
					if ($str !== '' && $time !== false && $time !== -1) {
						$str = date($option_values['date']['0'], $time + UNIX_ZONE);
					}
				}
			}

			// sani
			if (array_key_exists('sani', $option_values)) {
				if (!is_array($str) && $str !== '') {
					$str = strip_tags($str);
				}
			}

			// escape
			// & → &amp;
			// < → &lt;
			// > → &gt;
			// " → &quot;
			// ' → &#39;
//			if (array_key_exists('escape', $option_values)) {
//				if (!is_array($str) && $str !== '') {
//					//$str = htmlspecialchars($str, ENT_QUOTES, MAILFORMPHP_OUTPUT_ENCODE);
//					$str = htmlspecialchars($str, ENT_QUOTES);
//				}
//			}

			// br
			if (array_key_exists('br', $option_values)) {
				if (!is_array($str) && $str !== '') {
					$str = nl2br($str);
				}
			}

			// empty
			if (array_key_exists('empty', $option_values)) {
				if (!is_array($str) && $str === '') {
					$str = $option_values['empty']['0'] ? $option_values['empty']['0'] : '-';
				}
			}
		}
		if ($is_echo) {
			echo $str;
		} else {
			return $str;
		}
	}

	function input() {
		list ( $tagname, $type ) = explode('_', $this->conf['type']);
		if ($this->template_name == 'check') {
			// 確認
			$old_type = $type;
			$tagname = 'input';
			$type = 'hidden';
		} else if ($this->template_name == 'input') {
			// 入力
		} else if ($this->template_name == 'confirm') {
			// 送信
			$old_type = $type;
			$tagname = null;
		} else {
			return false;
		}
		$values = null;
		if ($this->conf['select_values']) {
			$values = explode($this->select_value_split, $this->conf['select_values']);
		}

		$id_prefix = $this->conf['form_id'] ? $this->conf['form_id'] : $this->prefix . 'id';
		$html = $this->formset($this->conf['setname'], $id_prefix); // return array
		$size = $this->conf['size'] ? $this->conf['size'] : 10 ; // default 10
		if (count($html) == 0) {

			switch ($tagname) {
				case 'select':
					$id = $id_prefix . '_' . $this->index;
					$html[] = '<select name="' . $this->name . '" id="' . $id . '">';
					$html[] = '<option value="">' . $this->jp['please_select'] . '</option>';
					foreach ($values as $k => $value) {
						$value = trim($value);
						if (!$value) {
							continue;
						}
						$selected = $this->form[$this->name] == $value ? $this->selected : '';
						$html[] = '<option value="' . htmlspecialchars($value, ENT_QUOTES) . '"' . $selected . '>' . $value . '</option>';
					}
					$html[] = '</select>';
					// value => 1
					break;

				case 'textarea':
					$cols = preg_match('/^\d+$/',$GLOBALS['cols_textarea']) ? $GLOBALS['cols_textarea'] : 30 ;
					$cols = preg_match('/^\d+$/',$this->conf['cols']) ? $this->conf['cols'] : $cols ;
					$rows = preg_match('/^\d+$/',$GLOBALS['rows_textarea']) ? $GLOBALS['rows_textarea'] : 10 ;
					$rows = preg_match('/^\d+$/',$this->conf['rows']) ? $this->conf['rows'] : $rows ;
					$id = $id_prefix . '_' . $this->index;
					$html[] = '<textarea name="' . $this->name . '" id="' . $id . '" cols="'.$cols.'" rows="'.$rows.'">' . htmlspecialchars($this->form[$this->name], ENT_QUOTES) . '</textarea>';
					// value => 1
					break;

				case 'input':
					switch ($type) {
						case 'checkbox':
							foreach ($values as $k => $value) {
								$value = trim($value);
								if (!$value) {
									continue;
								}
								$name = $this->name . '_' . $k;
								$checked = $this->form[$name] == $value ? $this->checked : '';
								$id = $id_prefix . '_' . $this->index . '_' . $k;
								$html[] = '<label for="' . $id . '"><input type="' . $type . '" name="' . $name . '" id="' . $id . '" value="' . htmlspecialchars($value, ENT_QUOTES) . '"' . $checked . $this->endtag . '>' . $value . '</label>';
							}
							// value => any
							break;

						case 'radio':
							foreach ($values as $k => $value) {
								$value = trim($value);
								if (!$value) {
									continue;
								}
								$checked = $this->form[$this->name] == $value ? $this->checked : '';
								$id = $id_prefix . '_' . $this->index . '_' . $k;
								$html[] = '<label for="' . $id . '"><input type="' . $type . '" name="' . $this->name . '" id="' . $id . '" value="' . htmlspecialchars($value, ENT_QUOTES) . '"' . $checked . $this->endtag . '>' . $value . '</label>';
							}
							// value => 1
							break;

						case 'text';
							$size = preg_match('/^\d+$/',$GLOBALS['size_input']) ? $GLOBALS['size_input'] : 20 ;
							$size = preg_match('/^\d+$/',$this->conf['size']) ? $this->conf['size'] : $size ;
							$id = $id_prefix . '_' . $this->index;
							$html[] = '<input type="' . $type . '" name="' . $this->name . '" id="' . $id . '" size="' . $size . '" value="' . htmlspecialchars($this->form[$this->name], ENT_QUOTES) . '"' . $this->endtag . '>';
							// value => 1
							break;

						case 'hidden';
							if ($values) {
								// 複数
								$addcount = 0;
								foreach ($values as $k => $value) {
									$name = $this->name . ( $old_type == 'checkbox' ? '_' . $k : '' );
									if ($value && $this->form[$name] == $value) {
										++$addcount;
										$id = $id_prefix . '_' . $this->index . '_' . $k;
										$html[] = '<div>' . ( $old_type == 'checkbox' ? $this->jp['list_marker'] : '' ) . $value . '</div>';
										$html[] = '<input type="' . $type . '" name="' . $name . '" id="' . $id . '" value="' . htmlspecialchars($value, ENT_QUOTES) . '"' . $checked . $this->endtag . '>';
									}
								}
								if ($addcount == 0) {
									$html[] = $this->jp['empty_select'];
								}
							} else {
								// 単一
								if (!$this->form[$this->name]) {
									$html[] = $this->jp['empty_input'];
								} else {
									$html[] = $this->convert($this->form[$this->name], $this->conf['output_options'], false);
								}
								$html[] = '<input type="' . $type . '" name="' . $this->name . '" id="' . $id . '" value="' . htmlspecialchars($this->form[$this->name], ENT_QUOTES) . '"' . $this->endtag . '>';
							}
							break;
					}
					break;

				case null:
					// メール用本文
					if ($values) {
						// 複数
						$addcount = 0;
						foreach ($values as $k => $value) {
							$name = $this->name . ( $old_type == 'checkbox' ? '_' . $k : '' );
							if ($value && $this->form[$name] == $value) {
								++$addcount;
								$id = $id_prefix . '_' . $this->index . '_' . $k;
								$html[] = ( $old_type == 'checkbox' ? $this->jp['list_marker'] : '' ) . $value;
							}
						}
						if ($addcount == 0) {
							$html[] = $this->jp['empty_select'];
						}
					} else {
						// 単一
						if (!$this->form[$this->name]) {
							$html[] = $this->jp['empty_input'];
						} else {
							$html[] = $this->convert($this->form[$this->name], $this->conf['output_options'], false);
						}
					}
					break;

				default:
					$html[] = '';
					break;
			}
		}
		$html = implode("\n", $html);
		if ($this->template_name == 'confirm') {
			// タグを除去して返却
			return strip_tags($html);
		} else {
			// 出力
			echo $html;
		}
	}

	// alias
	function value() {
		$this->input();
	}

	function formset($setname, $id_prefix) {
		$html = array();
		$id = $id_prefix . '_' . $this->index;
		if ($this->template_name == 'input') {
			$type = 'text';
		} else if ($this->template_name == 'check') {
			$type = 'hidden';
		} else if ($this->template_name == 'confirm') {
			$type = null;
		} else {
			return;
		}
		switch ($setname) {

			// 氏名セット
			case 'name1':
				$size = preg_match('/^\d+$/',$GLOBALS['size_name']) ? $GLOBALS['size_name'] : 8 ;
				if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->form[$this->name . '_name1']) {
						$html[] = $this->convert($this->form[$this->name . '_name1'], $this->conf['output_options'], false)
								. ' '
								. $this->convert($this->form[$this->name . '_name2'], $this->conf['output_options'], false);
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name == 'confirm') {
						break;
					}
				}
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name1">' . $this->jp['name_shi'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name1" id="' . $id . '_name1" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name1'], ENT_QUOTES) . '"' . $this->endtag . '>';
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name2">' . $this->jp['name_mei'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name2" id="' . $id . '_name2" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name2'], ENT_QUOTES) . '"' . $this->endtag . '>';
				break;
			// 姓名セット
			case 'name2':
				$size = preg_match('/^\d+$/',$GLOBALS['size_name']) ? $GLOBALS['size_name'] : 8 ;
				if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->form[$this->name . '_name1']) {
						$html[] = $this->convert($this->form[$this->name . '_name1'], $this->conf['output_options'], false)
								. ' '
								. $this->convert($this->form[$this->name . '_name2'], $this->conf['output_options'], false);
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name == 'confirm') {
						break;
					}
				}
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name1">' . $this->jp['name_sei'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name1" id="' . $id . '_name1" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name1'], ENT_QUOTES) . '"' . $this->endtag . '>';
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name2">' . $this->jp['name_mei'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name2" id="' . $id . '_name2" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name2'], ENT_QUOTES) . '"' . $this->endtag . '>';
				break;
			// シメイセット
			case 'name1_kata':
				$size = preg_match('/^\d+$/',$GLOBALS['size_namehira']) ? $GLOBALS['size_namehira'] : 10 ;
				if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->form[$this->name . '_name1']) {
						$html[] = $this->convert($this->form[$this->name . '_name1'], $this->conf['output_options'], false)
								. ' '
								. $this->convert($this->form[$this->name . '_name2'], $this->conf['output_options'], false);
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name == 'confirm') {
						break;
					}
				}
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name1">' . $this->jp['name_kata_shi'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name1" id="' . $id . '_name1" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name1'], ENT_QUOTES) . '"' . $this->endtag . '>';
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name2">' . $this->jp['name_kata_mei'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name2" id="' . $id . '_name2" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name2'], ENT_QUOTES) . '"' . $this->endtag . '>';
				break;
			// セイメイセット
			case 'name2_kata':
				$size = preg_match('/^\d+$/',$GLOBALS['size_namehira']) ? $GLOBALS['size_namehira'] : 10 ;
				if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->form[$this->name . '_name1']) {
						$html[] = $this->convert($this->form[$this->name . '_name1'], $this->conf['output_options'], false)
								. ' '
								. $this->convert($this->form[$this->name . '_name2'], $this->conf['output_options'], false);
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name == 'confirm') {
						break;
					}
				}
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name1">' . $this->jp['name_kata_sei'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name1" id="' . $id . '_name1" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name1'], ENT_QUOTES) . '"' . $this->endtag . '>';
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name2">' . $this->jp['name_kata_mei'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name2" id="' . $id . '_name2" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name2'], ENT_QUOTES) . '"' . $this->endtag . '>';
				break;
			// しめいセット
			case 'name1_hira':
				$size = preg_match('/^\d+$/',$GLOBALS['size_namehira']) ? $GLOBALS['size_namehira'] : 10 ;
				if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->form[$this->name . '_name1']) {
						$html[] = $this->convert($this->form[$this->name . '_name1'], $this->conf['output_options'], false)
								. ' '
								. $this->convert($this->form[$this->name . '_name2'], $this->conf['output_options'], false);
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name == 'confirm') {
						break;
					}
				}
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name1">' . $this->jp['name_hira_shi'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name1" id="' . $id . '_name1" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name1'], ENT_QUOTES) . '"' . $this->endtag . '>';
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name2">' . $this->jp['name_hira_mei'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name2" id="' . $id . '_name2" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name2'], ENT_QUOTES) . '"' . $this->endtag . '>';
				break;
			// せいめいセット
			case 'name2_hira':
				$size = preg_match('/^\d+$/',$GLOBALS['size_namehira']) ? $GLOBALS['size_namehira'] : 10 ;
				if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->form[$this->name . '_name1']) {
						$html[] = $this->convert($this->form[$this->name . '_name1'], $this->conf['output_options'], false)
								. ' '
								. $this->convert($this->form[$this->name . '_name2'], $this->conf['output_options'], false);
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name == 'confirm') {
						break;
					}
				}
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name1">' . $this->jp['name_hira_sei'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name1" id="' . $id . '_name1" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name1'], ENT_QUOTES) . '"' . $this->endtag . '>';
				if ($this->template_name == 'input') {
					$html[] = '<label for="' . $id . '_name2">' . $this->jp['name_hira_mei'] . '</label> ';
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_name2" id="' . $id . '_name2" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_name2'], ENT_QUOTES) . '"' . $this->endtag . '>';
				break;

			// メールセット
			case 'mail1': // 入力欄１つ
				$size = preg_match('/^\d+$/',$GLOBALS['size_mail']) ? $GLOBALS['size_mail'] : 30 ;
				if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->form[$this->name . '_mail']) {
						$html[] = $this->form[$this->name . '_mail'];
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name == 'confirm') {
						break;
					}
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_mail" id="' . $id . '_mail" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_mail'], ENT_QUOTES) . '"' . $this->endtag . '>';
				break;
			case 'mail2': // 入力欄２つ（＋同値確認）
				$size = preg_match('/^\d+$/',$GLOBALS['size_mail']) ? $GLOBALS['size_mail'] : 30 ;
				if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->form[$this->name . '_mail1']) {
						$html[] = $this->convert($this->form[$this->name . '_mail1'], $this->conf['output_options'], false);
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name == 'confirm') {
						break;
					}
				}
				if ($this->template_name == 'input') {
					$html[] = $this->jp['mail1'] . $this->tag['br'];
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_mail1" id="' . $id . '_mail1" size="'.$size.'" maxlength="255" value="' . htmlspecialchars($this->form[$this->name . '_mail1'], ENT_QUOTES) . '"' . $this->endtag . '>';
				if ($this->template_name == 'input') {
					$html[] = $this->tag['br'] . $this->jp['mail2'] . $this->tag['br'];
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_mail2" id="' . $id . '_mail2" size="'.$size.'" maxlength="255" value="' . htmlspecialchars($this->form[$this->name . '_mail2'], ENT_QUOTES) . '"' . $this->endtag . '>';

				break;

			// 電話セット
			case 'tel1': // 入力欄１つ
				$size = preg_match('/^\d+$/',$GLOBALS['size_tel1']) ? $GLOBALS['size_tel1'] : 15 ;
				if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->form[$this->name . '_tel']) {
						$html[] = $this->convert($this->form[$this->name . '_tel'], $this->conf['output_options'], false);
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name == 'confirm') {
						break;
					}
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_tel" id="' . $id . '_tel" size="15" value="' . htmlspecialchars($this->form[$this->name . '_tel'], ENT_QUOTES) . '"' . $this->endtag . '>';
				break;
			case 'tel2': // 入力欄３つ
				$size = preg_match('/^\d+$/',$GLOBALS['size_tel3']) ? $GLOBALS['size_tel3'] : 6 ;
				$split = ' - ';
				if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->form[$this->name . '_tel1'] && $this->form[$this->name . '_tel2'] && $this->form[$this->name . '_tel3']) {
						$html[] = $this->convert($this->form[$this->name . '_tel1'], $this->conf['output_options'], false) . $split
								. $this->convert($this->form[$this->name . '_tel2'], $this->conf['output_options'], false) . $split
								. $this->convert($this->form[$this->name . '_tel3'], $this->conf['output_options'], false);
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name == 'confirm') {
						break;
					}
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_tel1" id="' . $id . '_tel1" size="'.$size.'" maxlength="5" value="' . htmlspecialchars($this->form[$this->name . '_tel1'], ENT_QUOTES) . '"' . $this->endtag . '>'
						. ( $this->template_name == 'input' ? $split : '' )
						. '<input type="' . $type . '" name="' . $this->name . '_tel2" id="' . $id . '_tel2" size="'.$size.'" maxlength="4" value="' . htmlspecialchars($this->form[$this->name . '_tel2'], ENT_QUOTES) . '"' . $this->endtag . '>'
						. ( $this->template_name == 'input' ? $split : '' )
						. '<input type="' . $type . '" name="' . $this->name . '_tel3" id="' . $id . '_tel3" size="'.$size.'" maxlength="4" value="' . htmlspecialchars($this->form[$this->name . '_tel3'], ENT_QUOTES) . '"' . $this->endtag . '>'
				;
				break;

			// 住所セット
			case 'address1': // 郵便番号(1)、都道府県、        以下住所・番地、建物名
			case 'address2': // 郵便番号(1)、都道府県、市区町村、以下住所・番地、建物名
			case 'address3': // 郵便番号(2)、都道府県、        以下住所・番地、建物名
			case 'address4': // 郵便番号(2)、都道府県、市区町村、以下住所・番地、建物名
				$size_zip  = preg_match('/^\d+$/',$GLOBALS['size_zip' ]) ? $GLOBALS['size_zip' ] : 9 ;
				$size_zip1 = preg_match('/^\d+$/',$GLOBALS['size_zip1']) ? $GLOBALS['size_zip1'] : 4 ;
				$size_zip2 = preg_match('/^\d+$/',$GLOBALS['size_zip2']) ? $GLOBALS['size_zip2'] : 5 ;
				$size_city = preg_match('/^\d+$/',$GLOBALS['size_city']) ? $GLOBALS['size_city'] : 20 ;
				$size_addr = preg_match('/^\d+$/',$GLOBALS['size_addr']) ? $GLOBALS['size_addr'] : 30 ;
				$size_bldg = preg_match('/^\d+$/',$GLOBALS['size_bldg']) ? $GLOBALS['size_bldg'] : 30 ;

				$split = '-';

				if ($setname=='address1'||$setname=='address2') {
					$zip1 = '<input type="' . $type . '" name="' . $this->name . '_zip" id="' . $id . '_zip" size="'.$size_zip.'" maxlength="8" value="' . htmlspecialchars($this->form[$this->name . '_zip'], ENT_QUOTES) . '"' . $this->endtag . '>';
					$zip2 = '';
				} else if ($setname=='address3'||$setname=='address4') {
					$zip1 = '<input type="' . $type . '" name="' . $this->name . '_zip1" id="' . $id . '_zip1" size="'.$size_zip1.'" maxlength="3" value="' . htmlspecialchars($this->form[$this->name . '_zip1'], ENT_QUOTES) . '"' . $this->endtag . '>';
					$zip2 = '<input type="' . $type . '" name="' . $this->name . '_zip2" id="' . $id . '_zip2" size="'.$size_zip2.'" maxlength="4" value="' . htmlspecialchars($this->form[$this->name . '_zip2'], ENT_QUOTES) . '"' . $this->endtag . '>';
				}
				$btn = '<input type="submit" value="' . $this->jp['zip_search'] . '" name="'.$this->name.'_zipsearch"' . $this->endtag . '>';
				if ($this->template_name == 'input') {
					$pref_options[] = '<option value="">' . $this->jp['please_select'] . '</option>';
					foreach ($this->_prefs() as $pref) {
						$selected = $this->form[$this->name . '_pref'] == $pref ? $this->selected : '';
						$pref_options[] = '<option value="' . $pref . '"' . $selected . '>' . $pref . '</option>';
					}
					$pref = '<select name="' . $this->name . '_pref">' . implode('', $pref_options) . '</select>';
				} else if ($this->template_name == 'check') {
					$pref = '<input type="' . $type . '" name="' . $this->name . '_pref" id="' . $id . '_pref" value="' . htmlspecialchars($this->form[$this->name . '_pref'], ENT_QUOTES) . '"' . $this->endtag . '>';
				}
				$city = '';
				if ($setname=='address2'||$setname=='address4') {
					$city = '<input type="' . $type . '" name="' . $this->name . '_city" id="' . $id . '_city" size="'.$size_city.'" value="' . htmlspecialchars($this->form[$this->name . '_city'], ENT_QUOTES) . '"' . $this->endtag . '>';
				}
				$addr = '<input type="' . $type . '" name="' . $this->name . '_addr" id="' . $id . '_addr" size="'.$size_addr.'" value="' . htmlspecialchars($this->form[$this->name . '_addr'], ENT_QUOTES) . '"' . $this->endtag . '>';
				$bldg = '<input type="' . $type . '" name="' . $this->name . '_bldg" id="' . $id . '_bldg" size="'.$size_bldg.'" value="' . htmlspecialchars($this->form[$this->name . '_bldg'], ENT_QUOTES) . '"' . $this->endtag . '>';

				if ($this->template_name == 'input') {
					// 郵便番号
					$html[] = '<div class="formset_zip">';
					if ($setname=='address1'||$setname=='address2') {
					$html[] = $this->jp['zip'] . $this->tag['br'] . $zip1 . $btn;
					} else if ($setname=='address3'||$setname=='address4') {
					$html[] = $this->jp['zip'] . $this->tag['br'] . $zip1 . ' '.$split.' ' . $zip2 . $btn;
					}
					$html[] = '</div>';

					// 都道府県
					$html[] = '<div class="formset_pref">';
					$html[] = $this->jp['pref'] . $this->tag['br'] . $pref;
					$html[] = '</div>';

					// 市区町村
					if ($setname=='address2'||$setname=='address4') {
						$html[] = '<div class="formset_city">';
						$html[] = $this->jp['city'] . $this->tag['br'] . $city;
						$html[] = '</div>';
					}

					// 以下住所
					$html[] = '<div class="formset_addr">';
					$html[] = $this->jp['addr'] . $this->tag['br'] . $addr;
					$html[] = '</div>';

					// 建物名
					$html[] = '<div class="formset_bldg">';
					$html[] = $this->jp['bldg'] . $this->tag['br'] . $bldg;
					$html[] = '</div>';
				} else if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->template_name != 'confirm') {
						$html[] = '<div class="formset_address">';
					}
					if (
							( ($setname=='address1'||$setname=='address2') && $this->form[$this->name . '_zip'] )
							|| ( ($setname=='address3'||$setname=='address4') && $this->form[$this->name . '_zip1'] )
							|| ( ($setname=='address3'||$setname=='address4') && $this->form[$this->name . '_zip2'] )
							|| $this->form[$this->name . '_pref']
							|| ( ($setname=='address2'||$setname=='address4') && $this->form[$this->name . '_city'] )
							|| $this->form[$this->name . '_addr']
							|| $this->form[$this->name . '_bldg']
					) {
						if ($this->form[$this->name . '_zip']) {
							$html[] = $this->jp['zip_mark']
									. $this->convert($this->form[$this->name . '_zip1'], $this->conf['output_options'], false)
									. $this->tag['br'];
						}
						if ($this->form[$this->name . '_zip1'] && $this->form[$this->name . '_zip2']) {
							$html[] = $this->jp['zip_mark']
									. $this->convert($this->form[$this->name . '_zip1'], $this->conf['output_options'], false)
									. $split
									. $this->convert($this->form[$this->name . '_zip2'], $this->conf['output_options'], false)
									. $this->tag['br'];
						}
						$html[] = $this->form[$this->name . '_pref'] ? $this->convert($this->form[$this->name . '_pref'], $this->conf['output_options'], false) : '';
						if ($setname=='address2'||$setname=='address4') {
							$html[] = $this->form[$this->name . '_city'] ? $this->convert($this->form[$this->name . '_city'], $this->conf['output_options'], false) : '';
						}
						$html[] = $this->form[$this->name . '_addr'] ? $this->convert($this->form[$this->name . '_addr'], $this->conf['output_options'], false) : '';
						$html[] = $this->form[$this->name . '_bldg'] ? $this->tag['br'] . $this->convert($this->form[$this->name . '_bldg'], $this->conf['output_options'], false) : '';
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name != 'confirm') {
						$html[] = '</div>';
						$html[] = $zip1 . $zip2 . $pref . $city . $addr . $bldg;
					}
				}
				break;

			// 画像アップロード（サムネイル表示機能付き）
			case 'file1':
				if (MAILFORMPHP_PREFIX == 'p') {
					$original_name = 'old_filename';
					$file_name = 'old_filepath';
					if ($this->form[$this->name . '_' . $setname . '_' . $original_name]) {
						$html[] = '<div>';
						$html[] = $this->jp['uploaded_file'] . '<br>' . $this->form[$this->name . '_' . $setname . '_' . $original_name] . '<br>';
						$html[] = '<a href=".' . MAILFORMPHP_TEMP_DIR . DIRECTORY_SEPARATOR . $this->form[$this->name . '_' . $setname . '_' . $file_name] . '" target="_blank">'
								. '<img src=".' . MAILFORMPHP_TEMP_DIR . DIRECTORY_SEPARATOR . $this->form[$this->name . '_' . $setname . '_' . $file_name] . '" width="100">'
								. '</a>';
						$html[] = '<input type="hidden" name="' . $this->name . '_' . $setname . '_' . $original_name . '" value="' . htmlspecialchars($this->form[$this->name . '_' . $setname . '_' . $original_name], ENT_QUOTES) . '"' . $this->endtag . '>';
						$html[] = '<input type="hidden" name="' . $this->name . '_' . $setname . '_' . $file_name . '" value="' . htmlspecialchars($this->form[$this->name . '_' . $setname . '_' . $file_name], ENT_QUOTES) . '"' . $this->endtag . '>';
						$html[] = '</div>';
					}

					$new_file_name = 'upload_filename';
					if ($this->form[$this->name . '_' . $setname . '_' . $new_file_name]) {
						$html[] = '<div>';
						$html[] = $this->jp['new_upload_file'] . '<br>' . $this->form[$this->name . '_' . $setname]['name'] . '<br>';
						$html[] = '<a href=".' . MAILFORMPHP_TEMP_DIR . DIRECTORY_SEPARATOR . $this->form[$this->name . '_' . $setname . '_' . $new_file_name] . '" target="_blank">'
								. '<img src=".' . MAILFORMPHP_TEMP_DIR . DIRECTORY_SEPARATOR . $this->form[$this->name . '_' . $setname . '_' . $new_file_name] . '" width="100">'
								. '</a>';
						$html[] = '<input type="hidden" name="' . $this->name . '_' . $setname . '_' . $original_name . '" value="' . htmlspecialchars($this->form[$this->name . '_' . $setname]['name'], ENT_QUOTES) . '"' . $this->endtag . '>';
						$html[] = '<input type="hidden" name="' . $this->name . '_' . $setname . '_' . $file_name . '" value="' . htmlspecialchars($this->form[$this->name . '_' . $setname . '_' . $new_file_name], ENT_QUOTES) . '"' . $this->endtag . '>';
						$html[] = '</div>';
					}

					if ($this->template_name == 'input') {
						$html[] = '<input type="file" name="' . $this->name . '_' . $setname . '"' . $this->endtag . ' id="' . $id . '_' . $setname . '">';
					} else if ($this->template_name == 'check') {

					}
				}
				break;

			// 何でもアップロード
			case 'file2':
				if (MAILFORMPHP_PREFIX == 'p') {
					$original_name = 'old_filename';
					$file_name = 'old_filepath';
					if ($this->form[$this->name . '_' . $setname . '_' . $original_name]) {
						$html[] = '<div>';
						$html[] = $this->jp['uploaded_file'] . '<br>' . $this->form[$this->name . '_' . $setname . '_' . $original_name] . '<br>';
						$html[] = '<input type="hidden" name="' . $this->name . '_' . $setname . '_' . $original_name . '" value="' . htmlspecialchars($this->form[$this->name . '_' . $setname . '_' . $original_name], ENT_QUOTES) . '"' . $this->endtag . '>';
						$html[] = '<input type="hidden" name="' . $this->name . '_' . $setname . '_' . $file_name . '" value="' . htmlspecialchars($this->form[$this->name . '_' . $setname . '_' . $file_name], ENT_QUOTES) . '"' . $this->endtag . '>';
						$html[] = '</div>';
					}

					$new_file_name = 'upload_filename';
					if ($this->form[$this->name . '_' . $setname . '_' . $new_file_name]) {
						$html[] = '<div>';
						$html[] = $this->jp['new_upload_file'] . '<br>' . $this->form[$this->name . '_' . $setname]['name'] . '<br>';
						$html[] = '<input type="hidden" name="' . $this->name . '_' . $setname . '_' . $original_name . '" value="' . htmlspecialchars($this->form[$this->name . '_' . $setname]['name'], ENT_QUOTES) . '"' . $this->endtag . '>';
						$html[] = '<input type="hidden" name="' . $this->name . '_' . $setname . '_' . $file_name . '" value="' . htmlspecialchars($this->form[$this->name . '_' . $setname . '_' . $new_file_name], ENT_QUOTES) . '"' . $this->endtag . '>';
						$html[] = '</div>';
					}

					if ($this->template_name == 'input') {
						$html[] = '<input type="file" name="' . $this->name . '_' . $setname . '"' . $this->endtag . ' id="' . $id . '_' . $setname . '">';
					} else if ($this->template_name == 'check') {

					}
				}
				break;
			// URLセット
			case 'url1': // 入力欄１つ
				$size = preg_match('/^\d+$/',$GLOBALS['size_mail']) ? $GLOBALS['size_mail'] : 30 ;
				if ($this->template_name == 'check' || $this->template_name == 'confirm') {
					if ($this->form[$this->name . '_url']) {
						$html[] = $this->form[$this->name . '_url'];
					} else {
						$html[] = $this->jp['empty_input'];
					}
					if ($this->template_name == 'confirm') {
						break;
					}
				}
				$html[] = '<input type="' . $type . '" name="' . $this->name . '_url" id="' . $id . '_url" size="'.$size.'" value="' . htmlspecialchars($this->form[$this->name . '_url'], ENT_QUOTES) . '"' . $this->endtag . '>';
				break;
		}
		return $html; // array
	}

	var $prefs = array(
		// 北海道・東北
		'北海道', '青森県', '岩手県', '宮城県', '秋田県', '山形県', '福島県',
		// 関東
		'茨城県', '栃木県', '群馬県', '埼玉県', '千葉県', '東京都', '神奈川県',
		// 北陸・甲信越
		'新潟県', '富山県', '石川県', '福井県', '山梨県', '長野県',
		// 東海
		'岐阜県', '静岡県', '愛知県', '三重県',
		// 関西
		'滋賀県', '京都府', '大阪府', '兵庫県', '奈良県', '和歌山県',
		// 中国
		'鳥取県', '島根県', '岡山県', '広島県', '山口県',
		// 四国
		'徳島県', '香川県', '愛媛県', '高知県',
		// 九州・沖縄
		'福岡県', '佐賀県', '長崎県', '熊本県', '大分県', '宮崎県', '鹿児島県', '沖縄県',
	);

	function _prefs() {
		$prefs = $this->prefs ;
		if (MAILFORMPHP_DEFAULT_ENCODE !== MAILFORMPHP_OUTPUT_ENCODE) {
			$prefs = encode_filter($prefs, MAILFORMPHP_OUTPUT_ENCODE, MAILFORMPHP_DEFAULT_ENCODE);
		}
		return $prefs;
	}

	function get_check_param() {
		return array(
			'number' => array(
				'pattern' => '/^\d+$/',
				'message' => '半角数字のみ使用できます。',
			),
			'alphabet' => array(
				'pattern' => '/^[a-zA-Z]+$/',
				'message' => '半角英字のみ使用できます。',
			),
			'alnum' => array(
				'pattern' => '/^[0-9a-zA-Z]+$/',
				'message' => '半角英数字のみ使用できます。',
			),
			'alnumsign' => array(
				'pattern' => '/^[0-9a-zA-Z_\-]+$/',
				'message' => '半角英数字、アンダーバー(_)、ハイフン(-)が使用できます。',
			),
			'zip' => array(
				'pattern' => '/^\d{3}-?\d{2,4}$/',
				'message' => '入力が正しくありません。',
			),
			'hiragana' => array(
				'pattern' => '/^[ぁ-ゞー]+$/u',
				'message' => '全てひらがなで入力して下さい。',
			),
			'katakana' => array(
				'pattern' => '/^[ァ-ヾ]+$/u',
				'message' => '全てカタカナで入力して下さい',
			),
			'mail' => array(
				'pattern' => '/^[\x01-\x7F]+@(([-a-z0-9]+\.)*[a-z]+|\[\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}\])$/',
				'message' => '入力が正しくありません。',
			),
			'tel_both' => array(
				'pattern' => '/(^(?<!090|080|070|050)(^\d{2,5}?\-?\d{1,4}?\-?\d{4}$|^[\d\-]{12}$))|(^(090|080|070|050)(\-?\d{4}\-?\d{4}|[\\d-]{13})$)|(^0120(\-?\d{2,3}\-?\d{3,4}|[\d\-]{12})$)|(^0080\-?\d{3}\-?\d{4})/',
				'message' => '入力が正しくありません。',
			),
			'tel_hyphen' => array(
				'pattern' => '/(^(?<!090|080|070|050)(^\d{2,5}?\-\d{1,4}?\-\d{4}$|^[\d\-]{12}$))|(^(090|080|070|050)(\-\d{4}\-\d{4}|[\\d-]{13})$)|(^0120(\-\d{2,3}\-\d{3,4}|[\d\-]{12})$)|(^0080\-\d{3}\-\d{4})/',
				'message' => 'ハイフンが含まれていません。',
			),
			'tel_nohyphen' => array(
				'pattern' => '/(^(?<!090|080|070|050)\d{10}$)|(^(090|080|070|050)\d{8}$)|(^0120\d{6}$)|(^0080\d{7}$)/',
				'message' => '入力が正しくありません。（ハイフンは不要です）',
			),
			'url' => array(
				'pattern' => "/^\b(?:https?|shttp):\/\/(?:(?:[-_.!~*'()a-zA-Z0-9;:&=+$,]|%[0-9A-Fa-f][0-9A-Fa-f])*@)?(?:(?:[a-zA-Z0-9](?:[-a-zA-Z0-9]*[a-zA-Z0-9])?\.)*[a-zA-Z](?:[-a-zA-Z0-9]*[a-zA-Z0-9])?\.?|[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)(?::[0-9]*)?(?:\/(?:[-_.!~*'()a-zA-Z0-9:@&=+$,]|%[0-9A-Fa-f][0-9A-Fa-f])*(?:;(?:[-_.!~*'()a-zA-Z0-9:@&=+$,]|%[0-9A-Fa-f][0-9A-Fa-f])*)*(?:\/(?:[-_.!~*'()a-zA-Z0-9:@&=+$,]|%[0-9A-Fa-f][0-9A-Fa-f])*(?:;(?:[-_.!~*'()a-zA-Z0-9:@&=+$,]|%[0-9A-Fa-f][0-9A-Fa-f])*)*)*)?(?:\?(?:[-_.!~*'()a-zA-Z0-9;\/?:@&=+$,]|%[0-9A-Fa-f][0-9A-Fa-f])*)?(?:#(?:[-_.!~*'()a-zA-Z0-9;\/?:@&=+$,]|%[0-9A-Fa-f][0-9A-Fa-f])*)?$/",
				'message' => '入力が正しくありません。',
			)
		);
	}

	function validation(&$form) {
		// ※この関数内のエラー文は後でエンコード変換を行うので直接記述
		mb_regex_encoding(MAILFORMPHP_DEFAULT_ENCODE);
		$convert = array(
			// 前後の無駄な空白を除去
			'trim' => true,
			// タグを完全除去
			'sani' => true,
			// 半角数字 => 全角数字
			'hn2zn' => 'N',
			// 全角数字 => 半角数字
			'zn2hn' => 'n',
			// 半角英字 => 全角英字
			'hl2zl' => 'R',
			// 全角英字 => 半角英字
			'zl2hl' => 'r',
			// 半角英数字（＋記号） => 全角英数字（＋記号）
			'ha2za' => 'A',
			// 全角英数字（＋記号） => 半角英数字（＋記号）
			'za2ha' => 'a',
			// 半角カタカナ => 全角カタカナ
			'hk2zk' => 'KV',
			// 半角カタカナ => ひらがな
			'hk2zh' => 'HV',
			// 全角カタカナ => 半角カタカナ
			'zk2hk' => 'k',
			// 全角カタカナ => ひらがな
			'zk2zh' => 'c',
			// ひらがな => 全角カタカナ
			'zh2zk' => 'C',
			// ひらがな => 半角カタカナ
			'zh2hk' => 'h',
		);

		$check_param = $this->get_check_param() ;
		$err = array();
		for ($index = 0; $index <= $this->length; $index++) {
			$name = $this->prefix . 'name_' . $index;
			$conf = $this->setting[$index];

			// [順序]
			// (a)変換 > (b)必須確認 > (c)詳細確認
			// [ルール]
			// エラーが出た時点でその項目のチェックは終了
			// ※複数種のエラーがあったとしても最初の１つだけ

			$convert_options = explode(',', trim($conf['convert_options']));
			$required = trim($conf['required']);
			$check_options = explode('|', trim($conf['check_options']));

			// a
			if (isset($form[$name]) && $convert_options) {
				foreach ($convert_options as $option_code) {
					// 改行統一
					$form[$name] = str_replace("\r\n", "\n", $form[$name]);

					if (!isset($convert[$option_code])) {
						continue;
					}
					if ($option_code == 'trim') {
						$form[$name] = trim($form[$name]);
						continue;
					}
					if ($option_code == 'sani') {
						$form[$name] = strip_tags($form[$name]);
						continue;
					}
					$form[$name] = mb_convert_kana($form[$name], $convert[$option_code], MAILFORMPHP_DEFAULT_ENCODE);
				}

				// まずは必須チェック
				if ($required == 'yes') {
					if ($form[$name]=='') {
						$err[$name] = '必須項目です。';
					}
				}
				if (!array_key_exists($name,$err)) {
					$grep_pattern = array();
					$grep_word = array();
					foreach ($check_options as $option_code) {
						switch($option_code) {
							// 半角系
							case 'alpha_h_upper':
								$grep_pattern[] = '[A-Z]';
								$grep_word[] = '半角英字(大)';
								break;
							case 'alpha_h_lower':
								$grep_pattern[] = '[a-z]';
								$grep_word[] = '半角英字(小)';
								break;
							case 'h_number':
								$grep_pattern[] = '[0-9]';
								$grep_word[] = '半角数字';
								break;
							case 'hankana':
								$grep_pattern[] = '(?:\xEF\xBD[\xA1-\xBF]|\xEF\xBE[\x80-\x9F])';
								$grep_word[] = '半角カタカナ';
								break;

							// 全角形
							case 'alpha_z_upper':
								$grep_pattern[] = '[Ａ-Ｚ]';
								$grep_word[] = '全角英字(大)';
								break;
							case 'alpha_z_lower':
								$grep_pattern[] = '[ａ-ｚ]';
								$grep_word[] = '全角英字(小)';
								break;
							case 'z_number':
								$grep_pattern[] = '[０-９]';
								$grep_word[] = '全角数字';
								break;
							case 'hiragana':
								// $grep_pattern[] = 'ぁ-ゞー';
								$grep_pattern[] = '(\xe3\x81[\x81-\xbf]|\xe3\x82[\x80-\x9e])';
								$grep_word[] = 'ひらがな';
								break;
							case 'zenkana':
								$grep_pattern[] = '(\xe3\x82[\xa1-\xbf]|\xe3\x83[\x80-\xbe])';
								$grep_word[] = '全角カタカナ';
								break;

							// その他
							case 'other_r':
								$grep_pattern[] = '\r';
								$grep_word[] = '改行(CR)';
								break;
							case 'other_n':
								$grep_pattern[] = '\n';
								$grep_word[] = '改行(LF)';
								break;
							case 'other_t':
								$grep_pattern[] = '\t';
								$grep_word[] = 'タブ';
								break;
							case 'other_s':
								$grep_pattern[] = '\s';
								$grep_word[] = 'スペース';
								break;
						}

					}
					if ($grep_pattern) {
						if (!preg_match('@^('.implode('|',$grep_pattern).')+$@',$form[$name])) {
							$err[$name] = implode('、',$grep_word).'が入力できます';
						}
					}
				}
			}

			// b ( to c )
			// セットの場合
			if ($conf['setname']) {
				$doCheck = false;
				switch ($conf['setname']) {

					case 'name1':
					case 'name2':
						if ($required == 'yes') {
							if (( $form[$name . '_name1'] == '' || $form[$name . '_name2'] == '')) {
								$err[$name] = '必須項目です。';
							} else {
								$doCheck = true;
							}
						} else if ($form[$name . '_name1'] || $form[$name . '_name2']) {
							$doCheck = true;
						}

						if ($doCheck) {

						}


						break;
					case 'name1_kata':
					case 'name2_kata':
						$form[$name . '_name1'] = mb_convert_kana($form[$name . '_name1'], 'KVC', MAILFORMPHP_DEFAULT_ENCODE);
						$form[$name . '_name2'] = mb_convert_kana($form[$name . '_name2'], 'KVC', MAILFORMPHP_DEFAULT_ENCODE);

						if ($required == 'yes') {
							if (( $form[$name . '_name1'] == '' || $form[$name . '_name2'] == '')) {
								$err[$name] = '必須項目です。';
							} else {
								$doCheck = true;
							}
						} else if ($form[$name . '_name1'] || $form[$name . '_name2']) {
							$doCheck = true;
						}

						if ($doCheck) {
							if (
									!preg_match($check_param['katakana']['pattern'], $form[$name . '_name1'])
									|| !preg_match($check_param['katakana']['pattern'], $form[$name . '_name2'])
							) {
								$err[$name] = $check_param['katakana']['message'];
							}
						}

						break;
					case 'name1_hira':
					case 'name2_hira':
						$form[$name . '_name1'] = mb_convert_kana($form[$name . '_name1'], 'HVc', MAILFORMPHP_DEFAULT_ENCODE);
						$form[$name . '_name2'] = mb_convert_kana($form[$name . '_name2'], 'HVc', MAILFORMPHP_DEFAULT_ENCODE);

						if ($required == 'yes') {
							if (( $form[$name . '_name1'] == '' || $form[$name . '_name2'] == '')) {
								$err[$name] = '必須項目です。';
							} else {
								$doCheck = true;
							}
						} else if ($form[$name . '_name1'] || $form[$name . '_name2']) {
							$doCheck = true;
						}

						if ($doCheck) {
							if (
									!preg_match($check_param['hiragana']['pattern'], $form[$name . '_name1'])
									|| !preg_match($check_param['hiragana']['pattern'], $form[$name . '_name2'])
							) {
								$err[$name] = $check_param['hiragana']['message'];
							}
						}
						break;

					case 'mail1':
						$form[$name . '_mail'] = mb_convert_kana($form[$name . '_mail'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);

						if ($required == 'yes') {
							if ($form[$name . '_mail'] == '') {
								$err[$name] = '必須項目です。';
							} else {
								$doCheck = true;
							}
						} else if ($form[$name . '_mail'] != '') {
							$doCheck = true;
						}

						if ($doCheck) {
							if (substr_count($form[$name . '_mail'], '@') > 1) {
								$err[$name] = '@が２つ以上含まれています';
							} else if (!preg_match($check_param['mail']['pattern'], $form[$name . '_mail'])) {
								$err[$name] = '入力が正しくありません';
							}
						}

						if (!$err[$name]) {
							if($conf['recipients']=='yes'){
								$this->recipients = $form[$name . '_mail'];
							}
						}

						break;
					case 'mail2':
						$form[$name . '_mail1'] = mb_convert_kana($form[$name . '_mail1'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);
						$form[$name . '_mail2'] = mb_convert_kana($form[$name . '_mail2'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);

						if ($required == 'yes') {
							if (( $form[$name . '_mail1'] == '' || $form[$name . '_mail2'] == '')) {
								$err[$name] = '必須項目です。';
							} else {
								$doCheck = true;
							}
						} else if ($form[$name . '_mail1'] || $form[$name . '_mail2']) {
							$doCheck = true;
						}

						if ($doCheck) {
							if (substr_count($form[$name . '_mail1'], '@') > 1) {
								$err[$name] = '@が２つ以上含まれています';
							} else if (!preg_match($check_param['mail']['pattern'], $form[$name . '_mail1'])) {
								$err[$name] = '入力が正しくありません';
							} else if ($form[$name . '_mail1'] != $form[$name . '_mail2']) {
								$err[$name] = '一致しません。';
							}
						}

						if (!$err[$name]) {
							if($conf['recipients']=='yes'){
								$recipients = $form[$name . '_mail1'];
							}
						}

						break;

					case 'tel1':
						$form[$name . '_tel'] = mb_convert_kana($form[$name . '_tel'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);

						if ($required == 'yes') {
							if ($form[$name . '_tel'] == '') {
								$err[$name] = '必須項目です。';
							} else {
								$doCheck = true;
							}
						} else {
							// 必須ではなくても入力があればチェック
							if ($form[$name . '_tel'] != '') {
								$doCheck = true;
							}
						}

						if ($doCheck) {
							if (!preg_match($check_param['tel_hyphen']['pattern'], $form[$name . '_tel']) && !preg_match($check_param['tel_nohyphen']['pattern'], $form[$name . '_tel'])) {
								$err[$name] = '入力が正しくありません';
							}
						}
						break;

					case 'tel2':
						$form[$name . '_tel1'] = mb_convert_kana($form[$name . '_tel1'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);
						$form[$name . '_tel2'] = mb_convert_kana($form[$name . '_tel2'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);

						if ($required == 'yes') {
							if (( $form[$name . '_tel1'] == '' || $form[$name . '_tel2'] == '' || $form[$name . '_tel3'] == '')) {
								$err[$name] = '必須項目です。';
							} else {
								$doCheck = true;
							}
						} else if ($form[$name . '_tel1'] || $form[$name . '_tel2'] || $form[$name . '_tel3']) {
							$doCheck = true;
						}

						if ($doCheck) {
							$tel = $form[$name . '_tel1'] . $form[$name . '_tel2'] . $form[$name . '_tel3'];
							if (!preg_match($check_param['tel_hyphen']['pattern'], $tel) && !preg_match($check_param['tel_nohyphen']['pattern'], $tel)) {
								$err[$name] = '入力が正しくありません';
							}
						}

						break;

					case 'address1': // 郵便番号(1)、都道府県、        以下住所・番地、建物名
					case 'address2': // 郵便番号(1)、都道府県、市区町村、以下住所・番地、建物名
					case 'address3': // 郵便番号(2)、都道府県、        以下住所・番地、建物名
					case 'address4': // 郵便番号(2)、都道府県、市区町村、以下住所・番地、建物名

						if ($conf['setname']=='address1'||$conf['setname']=='address2') {
							$form[$name . '_zip'] = mb_convert_kana($form[$name . '_zip'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);
							if ($required == 'yes') {
								if ($form[$name . '_zip'] == '') {
									$address_error[] = '郵便番号は必須項目です。';
								} else {
									$doCheck = true;
								}
							} else if ($form[$name . '_zip'] != '') {
								$doCheck = true;
							}
							$zip = str_replace('-','',$form[$name . '_zip']);
						} else if ($conf['setname']=='address3'||$conf['setname']=='address4') {
							$form[$name . '_zip1'] = mb_convert_kana($form[$name . '_zip1'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);
							$form[$name . '_zip2'] = mb_convert_kana($form[$name . '_zip2'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);
							if ($required == 'yes') {
								if ($form[$name . '_zip1'] == '' || $form[$name . '_zip2'] == '') {
									$address_error[] = '郵便番号は必須項目です。';
								} else {
									$doCheck = true;
								}
							} else if ($form[$name . '_zip1'] != '' || $form[$name . '_zip2'] != '') {
								$doCheck = true;
							}
							$zip = $form[$name . '_zip1'] . $form[$name . '_zip2'];
						}

						if ($doCheck) {
							if (!preg_match($check_param['zip']['pattern'], $zip)) {
								$address_error[] = '郵便番号の入力が正しくありません。';
							}
						}

						$doCheck = false; // reset
						if ($required == 'yes') {
							if (!$form[$name . '_pref']) {
								$address_error[] = '都道府県は必須項目です。';
							} else {
								$doCheck = true;
							}
						} else if ($form[$name . '_pref']) {
							$doCheck = true;
						}

						if ($doCheck) {
							if (!in_array($form[$name . '_pref'], $this->prefs)) {
								$address_error[] = '都道府県の選択が正しくありません。';
							}
						}

						if ($conf['setname'] == 'address2') {
							$doCheck = false; // reset
							if ($required == 'yes') {
								if ($form[$name . '_city'] == '') {
									$address_error[] = '市区町村は必須項目です。';
								}
							}
						}

						$doCheck = false; // reset
						$form[$name . '_addr'] = mb_convert_kana($form[$name . '_addr'], 'RNAKV', MAILFORMPHP_DEFAULT_ENCODE);
						if ($required == 'yes') {
							if ($form[$name . '_addr'] == '') {
								$address_error[] = '以下住所・番地は必須項目です。';
							}
						}

						$doCheck = false; // reset
						$form[$name . '_bldg'] = mb_convert_kana($form[$name . '_bldg'], 'RNAKV', MAILFORMPHP_DEFAULT_ENCODE);
						if ($required == 'yes') {
							if ($form[$name . '_bldg'] == '') {
								$address_error[] = '建物名必須項目です。';
							}
						}

						if ($address_error)
							$err[$name] = implode(PHP_EOL, $address_error);

						break;

					case 'file1':
					case 'file2':
						if (MAILFORMPHP_PREFIX!='p') {
							break;
						}
						$arrow_extensions = array();
						$maxsize = '1 MB' ;
						$maxbyte = encodeSize($maxsize);
						$key = $name . '_' . $conf['setname'];
						if ($conf['check_options']) {

							$arrow_exts = explode('|',$conf['check_options']);
							foreach ( $arrow_exts as $ext ) {
								if (strpos($ext,':')!==false) {
									$exts = explode(':',$ext);

									if ($exts['0']=='other') {
										$other_exts = explode(',',$exts['1']);
										if ($other_exts) {
											foreach($other_exts as $other_ext) {
												if (preg_match('/^[a-z0-9]+$/i',$other_ext)) {
													$arrow_extensions[] = $other_ext ;
												}
											}
										}
									} else if ($exts['0']=='filesize') {
										if (preg_match('/^[0-9]+$/',$exts['1'])&&preg_match('/^[KMGTPEZY]B$/',$exts['2'])) {
											$maxsize = $exts['1'].' '.$exts['2'] ;
											$maxbyte = encodeSize($maxsize);
										}
									}

								} else {
									switch($ext) {
										case 'jpg':
											$arrow_extensions[] = $ext;
											$arrow_extensions[] = 'jpeg';
											$arrow_extensions[] = 'jpe';
											break;
										case 'doc':
										case 'xls':
										case 'ptt':
											$arrow_extensions[] = $ext;
											$arrow_extensions[] = $ext.'x';
											break;
										default:
											if (preg_match('/^[a-z0-9]+$/i',$ext)) {
												$arrow_extensions[] = $ext;
											}
											break;
									}
								}
							}
							$arrow_extensions = implode('|',$arrow_extensions);
						} else if ($conf['setname'] == 'file1') {
							// 画像ファイル用拡張子
							$arrow_extensions = 'jpg|gif|png|bmp';
						} else if ($conf['setname'] == 'file2') {
							// 一般ファイル用拡張子
							$arrow_extensions = 'zip|pdf|doc|docx|xls|xlsx';
						}

						$oldfile_exists = false;
						if ($form[$key]['old_filename']) {
							$oldfile_exists = true;
						}

						$gofilecheck = false;
						if ($conf['required'] == 'yes') {
							if (!$oldfile_exists) {
								if ($form[$key]['error'] == 4) {
									$err[$name] = 'ファイルをアップロードして下さい。';
									break;
								}
								$gofilecheck = true;
							}
						} else {
							if ($_FILES && $form[$key]['error'] != 4) {
								$gofilecheck = true;
							}
						}

						if ($gofilecheck) {
							// MAX_FILE_SIZEより大きなサイズ
							if ($form[$key]['error'] == 1) {
								$err[$name] = '処理できないサイズのファイルがアップロードされました。';
								break;
							}

							// アップロードされているかチェック
							if ($form[$key]['size'] <= 0) {
								$err[$name] = 'ファイルをアップロードして下さい。';
								break;
							}

							// 拡張子チェック
							if (!preg_match('/\.(' . $arrow_extensions . ')$/', $form[$key]['name'], $match)) {
								$err[$name] = 'アップロードできるファイルの種類は' . str_replace('|', '、', $arrow_extensions) . 'です。';
								break;
							} else {
								$ext = $match['1'];
							}

							// サイズチェック
							if (!preg_match("/^\d+$/", $maxbyte) || $maxbyte <= 0) {
								$err[$name] = 'アップロード可能なバイト数が正しく設定されていません。settingファイルをご確認下さい。';
								break;
							} elseif ($form[$key]['size'] > $maxbyte) {
								$err[$name] = 'アップロード可能なバイト数を超えました。アップロードできる容量は'.$maxsize.'までです。';
								break;
							}

							// アップロード元チェック
							if (!is_uploaded_file($form[$key]['tmp_name'])) {
								$err[$name] = 'フォームよりアップロードして下さい。';
								break;
							}

							$form[$key . '_upload_filename'] = sha1(uniqid(mt_rand())) . '.' . $ext;
							$form[$key . '_upload_filepath'] = MAILFORMPHP_UPLOADS_DIR . DIRECTORY_SEPARATOR . $form[$key . '_upload_filename'];

							if (move_uploaded_file($form[$key]['tmp_name'], $form[$key . '_upload_filepath'])) {
								chmod($form[$key . '_upload_filepath'], 0666);
							} else {
								$err[$name] = 'アップロードに失敗しました。';
							}
						}
						break;
					case 'url1':
						$form[$name . '_url'] = mb_convert_kana($form[$name . '_url'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);

						if ($required == 'yes') {
							if ($form[$name . '_url'] == '') {
								$err[$name] = '必須項目です。';
							} else {
								$doCheck = true;
							}
						} else {
							// 必須ではなくても入力があればチェック
							if ($form[$name . '_url'] != '') {
								$doCheck = true;
							}
						}

						if ($doCheck) {
							if (!preg_match($check_param['url']['pattern'], $form[$name . '_url'])) {
								$err[$name] = '入力が正しくありません';
							}
						}
						break;
				}
			}
			// チェックボックスの場合の確認
			else if ($conf['type'] == 'input_checkbox') {

				if (!$conf['select_values']) {
					continue;
				}

				$values = explode("\n", $conf['select_values']);
				$checked = 0;
				foreach ($values as $k => $value) {
					$value = trim($value);
					if (!$value) {
						continue;
					}
					if (isset($form[$name . '_' . $k]) && $form[$name . '_' . $k] == $value) {
						$checked++;
					}
				}

				if ($required == 'yes' && $checked == 0) {
					$err[$name] = '１つ以上選択して下さい';
					continue;
				}

				// n個までチェック可能 とか？
			}
			// 単一値の場合
			else {
				$doCheck = false;
				// $form[ $name ] = trim( $form[ $name ] );
				if ($required == 'yes') {
					if ($form[$name] == '') {
						$err[$name] = '必須項目です。';
					} else {
						$doCheck = true;
					}
				} else if ($form[$name]) {
					$doCheck = true;
				}

				// エラーがあれば次の項目へ
				if ($err[$name] != '') {
					continue;
				}

				if ($doCheck && $check_options) {
					foreach ($check_options as $option) {
						if ($err[$name]) {
							continue;
						}
						if (isset($check_param[$option])) {
							if (!preg_match($check_param[$option]['pattern'], $form[$name])) {
								$err[$name] = $check_param[$option]['message'];
							}
						}
					}
				}
			}
		}

		return $err;
	}

	function run(){

		$request = $_POST ? $_POST : $_GET;
		$this->form = post_filter($request);
		if ($_FILES) {
			$this->form = array_merge($this->form, $_FILES);
			$file_keys = array_keys($_FILES);
		}

		// -- ポストされた値をPHP内で処理できるようにエンコード
		if (MAILFORMPHP_DEFAULT_ENCODE !== MAILFORMPHP_OUTPUT_ENCODE) {
			$this->form = encode_filter($this->form, MAILFORMPHP_DEFAULT_ENCODE, MAILFORMPHP_OUTPUT_ENCODE);
		}

		$this->getSetting();
		$this->startSession();

		$this->template_name = null;

		$keys = array_keys($this->form);
		$goZipsearch = false;
		$this->zipsearch = false;
		foreach($keys as $key) {
			if (preg_match('/^(.*)_zipsearch$/',$key,$match)){
				$goZipsearch = true;
				$this->zipsearch = $match['1'];
				break;
			}
		}

		switch (true) {

			case isset($this->form['check']):
				if (!$this->session->check('input|check')) {
					// 入力画面からのアクセスではない場合エラー
					$this->err['message'] = $this->session->message();
					$this->template_name = 'error';
					$this->session->destroy();
					break;
				}

				// バリデーション
				$this->err = $this->validation($this->form);
				if ($this->err) {
					$this->template_name = 'input';
					$this->session->update($this->template_name);
					break;
				}
				$this->template_name = 'check';
				$this->session->update($this->template_name);
				break;

			case isset($this->form['back']):
				if (!$this->session->check('check|input')) {
					// 確認画面からのアクセスではない場合エラー
					$this->err['message'] = $this->session->message();
					$this->template_name = 'error';
					$this->session->destroy();
					break;
				}
				$this->template_name = 'input';
				$this->session->update($this->template_name);
				break;

			case isset($this->form['confirm']):
				if (!$this->session->check('check')) {
					// 確認画面からのアクセスではない場合エラー
					$this->err['message'] = $this->session->message();
					$this->template_name = 'error';
					break;
				}

				// バリデーション
				$this->err = $this->validation($this->form);
				if ($this->err) {
					$this->template_name = 'input';
					$this->session->update($this->template_name);
					break;
				}
				$this->template_name = 'confirm';
				break;

			case isset($this->form['finish']):
				if (!$this->session->check('confirm|finish')) {
					// 送信処理後からのアクセスではない場合エラー
					$this->err['message'] = $this->session->message();
					$this->template_name = 'error';
					break;
				}
				$this->template_name = 'finish';
				$this->session->destroy();
				break;

			case $goZipsearch:
				if (!$this->session->check('input')) {
					// 入力画面からのアクセスではない場合エラー
					$this->err['message'] = $this->session->message();
					$this->template_name = 'error';
					$this->session->destroy();
					break;
				}

				$this->err = $this->zipSearch($this->form);

				$this->template_name = 'input';
				$this->session->update($this->template_name);
				break;

			default:
				$this->template_name = 'input';
				if (!$this->session->create($this->template_name)) {
					// 生成失敗時
					$this->template_name = 'error';
					$this->err['message'] = $this->session->message();
				}
				break;
		}




		if ($this->template_name != 'confirm') {
			// -- 出力用に再エンコード
			if (MAILFORMPHP_DEFAULT_ENCODE !== MAILFORMPHP_OUTPUT_ENCODE) {
				$this->form = encode_filter($this->form, MAILFORMPHP_OUTPUT_ENCODE, MAILFORMPHP_DEFAULT_ENCODE);
				$this->err = encode_filter($this->err, MAILFORMPHP_OUTPUT_ENCODE, MAILFORMPHP_DEFAULT_ENCODE);
				$this->setting = encode_filter($this->setting, MAILFORMPHP_OUTPUT_ENCODE, MAILFORMPHP_DEFAULT_ENCODE);
			}
			$this->display();
		} else {
			if (MAILFORMPHP_DEFAULT_ENCODE !== MAILFORMPHP_OUTPUT_ENCODE) {
				$this->jp = encode_filter($this->jp, MAILFORMPHP_DEFAULT_ENCODE, MAILFORMPHP_OUTPUT_ENCODE);
			}
			if (!DEMO_MODE) {
				// デモモードじゃ無ければ
				$this->sendmail();
				$param['demo'] = 1;
			}
			$this->session->update($this->template_name);
			$param['finish'] = time();
			$param[MAILFORMPHP_SESSION_NAME] = $this->session->getKey();
			$param['number'] = $this->counter ; // お問合せ番号
			header('Location: ./?' . http_build_query($param));
		}
	}

	function makeMailValue(){
		$this->thanks_value = null;
		$this->alert_value = null;
		for ($i = 0; $i < $this->length; $i++) {
			$this->setIndex($i);
			$is_uploader = preg_match('/^file[12]$/', $this->conf['setname']);

			if (MAILFORMPHP_PREFIX!='p'&&$is_uploader) {
				continue;
			}

			// 見出し（テンプレートと同じエンコード）
			$this->thanks_value .= '■' . $this->html('title') . MAIL_EOL;
			$this->alert_value .= '■' . $this->html('title') . MAIL_EOL;

			// ファイルアップロードかどうか調べる
			// @todo アップロードされたファイルの添付・ダウンロード方法について1回まとめ直す
			if ($is_uploader) {
				// 確認メール用
				$this->thanks_value .= $this->form[$this->name . '_' . $this->conf['setname'] . '_old_filename'] . MAIL_EOL;

				// 通知メール用
				if ($this->form[$this->name . '_' . $this->conf['setname'] . '_old_filepath']) {
					// ファイル移動
					rename(
						MAILFORMPHP_UPLOADS_DIR.DIRECTORY_SEPARATOR.$this->form[$this->name . '_' . $this->conf['setname'] . '_old_filepath'],
						MAILFORMPHP_BASE_DIR.DIRECTORY_SEPARATOR.MAILFORMPHP_FILE_DIR.DIRECTORY_SEPARATOR.$this->form[$this->name . '_' . $this->conf['setname'] . '_old_filepath']
					);
					// ファイルリストへ保存
					makefile(
						MAILFORMPHP_FILELIST,
						$this->form[$this->name . '_' . $this->conf['setname'] . '_old_filename']
						."\t".$this->form[$this->name . '_' . $this->conf['setname'] . '_old_filepath']
						."\t".time()
						."\n",
						'a');
					list($filecode,) = explode('.',$this->form[$this->name . '_' . $this->conf['setname'] . '_old_filepath']);
					$this->alert_value .= '※以下よりダウンロードできます' . MAIL_EOL ;
					$this->alert_value .= MAILFORMPHP_BASEURL . 'filedownload.php?filecode=' . $filecode . MAIL_EOL ;
				}
			} else {
				// 値（PHPと同じエンコード）
				$this->thanks_value .= $this->input() . MAIL_EOL;
				$this->alert_value .= $this->input() . MAIL_EOL;
			}
		}
	}

	function getMailValue($type,$tag){
		$value = '';
		switch($tag){
			case 'mailform':
				if ($type=='thanks_mail') {
					// 確認メール用
					$value = $this->thanks_value;
				} else if ($type=='alert_mail'){
					// 通知メール用
					$value = $this->alert_value;
				}
				break;
			case 'date':
				$value = date('Y年m月d日 H時i分',UNIX_TIME);
				break;
			case 'number':
				$value = $this->counter ;
				break;
			case 'ip':
				$value = $_SERVER['REMOTE_ADDR'];
				break;
			case 'user_agent':
				$value = $_SERVER['HTTP_USER_AGENT'];
				break;
			default:
				break;
		}
		return $value ;
	}

	function replaceBody($type,$body){
		// $typeによって置換タグの処理を分ける
		$is = $this->replace_kind[$type];

		foreach($is as $tag => $flag){
			if (!$flag) continue;
			$body = str_replace('{'.$tag.'}',$this->getMailValue($type,$tag),$body);
		}

		return $body;
	}

	function sendmail(){
		global $global_params;

		// iso-2022-jp(-ms)を取得
		$iso2022jp = get_iso2022jp();

		$send = array();
		// 確認メール
		$send[] = array(
			'type' => 'thanks_mail',
			'isSend' => $global_params['thanks_mail']['use']==1 ? true : false ,
			'recipients' => $this->recipients,
			'subject' => $global_params['thanks_mail']['subject'],
			'body' => $global_params['thanks_mail']['body'],
		);

		// 通知メール
		$send[] = array(
			'type' => 'alert_mail',
			'isSend' => true ,
			'recipients' => $global_params['alert_mail']['recipients'],
			'subject' => $global_params['alert_mail']['subject'],
			'body' => $global_params['alert_mail']['body'],
		);

		// 通知(小)メール
		$send[] = array(
			'type' => 'pop_mail',
			'isSend' => $global_params['pop_mail']['recipients']&&$global_params['alert_mail']['subject']&&$global_params['alert_mail']['body'] ? true : false ,
			'recipients' => $global_params['pop_mail']['recipients'],
			'subject' => $global_params['pop_mail']['subject'],
			'body' => $global_params['pop_mail']['body'],
		);

		// 送り元指定
		$from = '';
		if($global_params['from']['name']!='') {
			$from .= mb_encode_mimeheader(mb_convert_encoding($global_params['from']['name'],$iso2022jp,MAILFORMPHP_DEFAULT_ENCODE));
			$from .= ' <'.$global_params['from']['mail'].'>';
		} else {
			$from = $global_params['from']['mail'];
		}

		$body_encode = array(
			// ヘッダは-msを付けない
			"head_charset" => 'iso-2022-jp',
			"text_charset" => $iso2022jp
		);

		require_once 'Mail.php';
		require_once 'Mail/mime.php';

		$hasError = false ;

		// メール本文の準備
		$this->makeMailValue();

		// ここでファイルロック
		$lockfile = MAILFORMPHP_SESSION_DIR . '/__COUNTER.LOCK' ;
		$counterfile = MAILFORMPHP_LIBS_DIR . '/counter.cgi' ;
		$lockfp = fopen($lockfile,'w');
		flock($lockfp, LOCK_EX);

		$this->counter = (int) file_get_contents($counterfile) ;
		$this->counter++;
		$fp = fopen($counterfile,'wb+');
		stream_set_write_buffer($fp, 0);
		flock($fp, LOCK_EX);
		rewind($fp);
		fwrite($fp,$this->counter);

		mb_internal_encoding($iso2022jp);

		// 順にメール送信処理
		foreach( $send as $m ){
			// フラグが立ってなければ次の処理へ
			if(!$m['isSend']) continue ;

			// PEAR::Mail_Mime オブジェクト生成
			$mime = new Mail_Mime(MAIL_EOL);

			// PEAR::Mail オブジェクト生成
			if($global_params['smtpauth_params']['auth']==1){
				$mail = Mail::factory("smtp", $global_params['smtpauth_params']);
			} else {
				$mail = Mail::factory("mail");
			}

			// 本文内のタグ変換
			$m['body'] = $this->replaceBody($m['type'],$m['body']);

			if (strtolower($iso2022jp)=='iso-2022-jp') {
				$dCode = new dependentCode;
				$m['body'] = $dCode->replace($m['body']);
			}

			$m['body'] = html_entity_decode($m['body'], ENT_QUOTES);

			$body = mb_convert_encoding($m['body'],$iso2022jp,MAILFORMPHP_DEFAULT_ENCODE);
			$subject = mb_convert_encoding($m['subject'],$iso2022jp,MAILFORMPHP_DEFAULT_ENCODE);

			// $mime->setTxtBody();
			// $body = $mime->get($body_encode);

			// メールヘッダ情報を連想配列としてセット
			$headers = array(
				// To欄に入れるだけの物、実際に送信する先は$recipients
				"To" => $m['recipients'],
				// 送り元
				"From" => $from,
				// 日本語の件名を指定する場合、mb_encode_mimeheaderでエンコード
				"Subject" => mb_encode_mimeheader($subject)
			);

			$header = $mime->headers($headers);

			$result = $mail->send($m['recipients'], $header, $body);
			if (PEAR::isError($result)){
				$this->err[] = $result;
			}

		}
		mb_internal_encoding(MAILFORMPHP_DEFAULT_ENCODE);

		// ファイルロック解除
		flock($fp, LOCK_UN);
		fclose($fp);
		flock($lockfp, LOCK_UN);
		fclose($lockfp);
		unlink($lockfile);

		if ($hasError){
			$this->err[] = $global_params;
			exit(0);
		}
	}

	/**
	* テンプレート出力
	*
	* @return	無し
	*/
	function display() {
		if ($this->template_name === null) {
			die('error: ' . $this->template_name);
		}
		mb_http_output(MAILFORMPHP_OUTPUT_ENCODE);
		header('Content-type: ' . ( strtolower(MAILFORMPHP_USERTYPE) == 'docomo' ? 'application/xml+xhtml' : 'text/html' ) . '; charset=' . MAILFORMPHP_OUTPUT_ENCODE . ';');
		$main_tpl = MAILFORMPHP_PREFIX . '.' . $this->template_name . '.html';
		if (!file_exists(MAILFORMPHP_TEMPLATES_DIR . DIRECTORY_SEPARATOR . $main_tpl)) {
			die('not fount: ' . $main_tpl);
		}

		$mailform = $this;

		// テンプレート呼び出し
		ob_start();
		require MAILFORMPHP_TEMPLATES_DIR . DIRECTORY_SEPARATOR . MAILFORMPHP_PREFIX . '.header.html';
		require MAILFORMPHP_TEMPLATES_DIR . DIRECTORY_SEPARATOR . $main_tpl;
		require MAILFORMPHP_TEMPLATES_DIR . DIRECTORY_SEPARATOR . MAILFORMPHP_PREFIX . '.footer.html';
		$html = ob_get_contents();
		ob_end_clean();
		if(checkCode(getLicenseCode())||preg_match('/k\s*a\s*n\s*t\s*a\s*r\s*o\s*\-\s*c\s*g\s*i\s*\.\s*c\s*o\s*m/i',$html)){echo $html;}else{echo 'need copyright.';}
	}

	function check_smtpauth($host,$port,$username,$password,$debug=false){
		require 'Mail.php';
		$param = array(
			'debug' => $debug,
			'host' => $host,		// SMTPサーバー名
			'port' => $port,		// ポート番号
			'auth' => true,			// SMTP認証を使用する
			'username' => $username,// SMTPのユーザー名
			'password' => $password,// SMTPのパスワード
			'timeout' => 5,
		);
		$mail = Mail::factory("smtp", $param);
		$result = $mail->getSMTPObject();
		if (PEAR::isError($result)) {
			return trim($result->message);
		}
		if ($result->_arguments) {
			return implode('\n',$result->_arguments);
		}
		return print_r($result) ;
	}

	function zipSearch(&$form){
		mb_regex_encoding(MAILFORMPHP_DEFAULT_ENCODE);
		$check_param = $this->get_check_param() ;
		$err = array();
		$name = $this->zipsearch;
		$index = str_replace($this->prefix.'name_','',$name);
		$conf = $this->setting[$index];

		if (preg_match('/^address[1-4]$/',$conf['setname'])) {
			if ($conf['setname']=='address1'||$conf['setname']=='address2') {
				$form[$name . '_zip'] = mb_convert_kana($form[$name . '_zip'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);
				if ($required == 'yes') {
					if ($form[$name . '_zip'] == '') {
						$address_error[] = '郵便番号は必須項目です。';
					} else {
						$doCheck = true;
					}
				} else if ($form[$name . '_zip'] != '') {
					$doCheck = true;
				}
				$zip = $form[$name . '_zip'];
			} else if ($conf['setname']=='address3'||$conf['setname']=='address4') {
				$form[$name . '_zip1'] = mb_convert_kana($form[$name . '_zip1'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);
				$form[$name . '_zip2'] = mb_convert_kana($form[$name . '_zip2'], 'rna', MAILFORMPHP_DEFAULT_ENCODE);
				if ($required == 'yes') {
					if ($form[$name . '_zip1'] == '' || $form[$name . '_zip2'] == '') {
						$address_error[] = '郵便番号は必須項目です。';
					} else {
						$doCheck = true;
					}
				} else if ($form[$name . '_zip1'] != '' || $form[$name . '_zip2'] != '') {
					$doCheck = true;
				}
				$zip = $form[$name . '_zip1'] . $form[$name . '_zip2'];
			}

			if ($doCheck) {
				if (!preg_match($check_param['zip']['pattern'], $zip)) {
					$address_error[] = '郵便番号の入力が正しくありません。';
				}
			}

			if (!$address_error) {

				$hit = $this->_getZipcode($zip);
				if (!$hit['pref']||!$hit['city']) {
					$address_error[] = ($zip?$zip.'に':'').'該当する住所が見つかりませんでした';
				} else {
					$form[$name . '_pref'] = $hit['pref'] ;
					if ($conf['setname'] == 'address2') {
						$form[$name . '_city'] = $hit['city'] ;
						$form[$name . '_addr'] = $hit['addr'] ;
					} else {
						$form[$name . '_addr'] = $hit['city'].$hit['addr'] ;
					}
				}
			}

			if ($address_error) {
				$err[$name] = implode(PHP_EOL, $address_error);
			}
		}
		return $err;
	}

	function _getZipcode($zip){
		$zip = str_replace('-', '', trim($zip));
		if (!strlen($zip) === 7 || !is_numeric($zip)) {
			return false;
		}

		$zip = preg_replace('/^(\d{3})(\d{4})$/', '$1-$2', $zip);

		$params['langpair'] = 'ja-Hira|ja';
		$params['jsonp'] = time();
		$params['text'] = $zip;

		$last_request_url = 'http://www.google.com/transliterate?' . http_build_query($params);

		$get_data = file_get_contents($last_request_url);

		$ret = json_decode($get_data);
		$address = $ret['0']['1']['0'];
		preg_match('/^(.*?(東京都|道|府|県))((?:蒲郡市|.*郡山市)|(?:.*郡(?:玉村町|大町町|鹿町町|.*?[町村]))|((?:札幌|仙台|さいたま|千葉|横浜|川崎|新潟|静岡|浜松|名古屋|京都|大阪|堺|神戸|広島|北九州|福岡)市.*区)|(四日市市|廿日市市|.*?[市区])|([^郡]+?[町村]))(.*)?/u', $address, $match);

		return array(
			'pref' => $match['1'],
			'city' => $match['3'],
			'addr' => $match['7'],
		);
	}
}

function renderHeader($title=null, $use_jquery=true, $use_common=true){
	$jquery_ver = '1.10.2';
	$jqueryui_ver = '1.10.3';
	$jqueryui_theme = 'flick';

	header( 'Content-Type:text/html; charset=' . MAILFORMPHP_DEFAULT_ENCODE );
	$html[] = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">';
	$html[] = '<html lang="ja">';
	$html[] = '<head>';
	$html[] = '<meta http-equiv="Content-Type" content="text/html;charset='.MAILFORMPHP_DEFAULT_ENCODE.'">';
	$html[] = '<title>'.$title.'</title>';
	if ($use_jquery) {
		if ($use_common) {
			// オフライン用
			$html[] = '<script type="text/javascript" src="./common/admin/js/jquery-'.$jquery_ver.'.min.js"></script>';
			$html[] = '<script type="text/javascript" src="./common/admin/js/jquery-ui-'.$jqueryui_ver.'.custom.min.js"></script>';
			$html[] = '<link type="text/css" href="./common/admin/css/'.$jqueryui_theme.'/jquery-ui-'.$jqueryui_ver.'.custom.css" rel="stylesheet" />';
		} else {
			// オンライン用
			$html[] = '<script type="text/javascript" src="//ajax.googleapis.com/ajax/libs/jquery/'.$jquery_ver.'/jquery.min.js"></script>';
			$html[] = '<script type="text/javascript" src="//ajax.googleapis.com/ajax/libs/jqueryui/'.$jqueryui_ver.'/jquery-ui.min.js"></script>';
			$html[] = '<link rel="stylesheet" href="//ajax.googleapis.com/ajax/libs/jqueryui/'.$jqueryui_ver.'/themes/'.$jqueryui_theme.'/jquery-ui.css" />';
 		}
	}
	$html[] = '</head>';
	$html[] = '<body>';
	return implode("\n",$html);
}

function renderFooter(){
	$html[] = '</body>';
	$html[] = '</html>';
	return implode("\n",$html);
}

function myAuth(){
	$go_setup = false ;
	$account_path = MAILFORMPHP_ACCOUNT ;
	$account_file = str_replace( MAILFORMPHP_LIBS_DIR . DIRECTORY_SEPARATOR, '', $account_path );

	if (!file_exists($account_path)) {
		// アカウントファイルが無い
		$go_setup = true ;
	} else {
		require_once $account_path ; // load $user
		$check_param = mailform::get_check_param();
		$username_pattern = $check_param['mail']['pattern'] ;
		$password_pattern = '/^[a-zA-Z0-9]{4,}$/' ;
		if (!isset($user)
			|| !preg_match($username_pattern,key($user))
			|| !preg_match($password_pattern,$user[key($user)])
			) {

			if (!is_writable($account_path)) {
				// ファイルの書き込み権限が無い
				renderHeader('エラー',true);
				echo '<div style="padding:.5em;" class="ui-state-error ui-corner-all">';
				echo 'ファイルの変更権限がありません。ファイル（'.$account_file.'）やフォルダ（'.MAILFORMPHP_LIBS_DIR.'/）のパーミッションを確認して下さい。';
				echo '</div>';
				renderFooter();
				exit(0);
			}

			$go_setup = true ;
		}
	}
	if ( (!DEMO_MODE) && $go_setup) {
		exit( setup() );
	}

	// データ整理
	$username = key($user);
	$password = $user[$username];

	if( DEMO_MODE ) {
		$username = 'demo@kantaro-cgi.com';
		$password = '593c0ecf735692da7ba40046cc475445';
	}

	require_once 'Auth.php';
	$options = array(
		'enableLogging' => false,
		'cryptType' => 'md5',
		'users' => array($username=>$password),
	);
	$auth =  new Auth("Array", $options, "loginFunction");

	$sname = session_name() ;
	if(isset($_GET['logout'])&&$auth->checkAuth()) {
		$auth->logout();
		$_SESSION=array();
		if (isset($_COOKIE[$sname])) {
			setcookie($sname, "", time()-42000);
		}
		session_destroy();
	}

	$auth->start();
	if (!$auth->getAuth()) {
		// 認証していなければログインフォームが出るのでここで止める
		exit(0);
	}
	return $username ;
}

function setup(){
	$valid_mailaddress = false ;
	if ($_POST&&isset($_POST['setup'])) {
		$check_param = mailform::get_check_param();
		if (substr_count($_POST['mailaddress'], '@') > 1) {
			$msg = 'メールアドレスは１つだけ入力して下さい';
		} else if (!preg_match($check_param['mail']['pattern'],$_POST['mailaddress'])) {
			$msg = 'メールアドレスを正しく入力して下さい';
		} else {
			$valid_mailaddress = true ;
		}
	}

	if($valid_mailaddress) {
		$newpassword = makepw(16);

		$save_result = makeAccount($_POST['mailaddress'],$newpassword);
		if ($save_result) {

			// iso-2022-jp(-ms)を取得
			$iso2022jp = get_iso2022jp();

			// 送り元指定
			$from = $_POST['mailaddress'];

			$body_encode = array(
				"head_charset" => $iso2022jp,
				"text_charset" => $iso2022jp
			);

			require_once 'Mail.php';
			require_once 'Mail/mime.php';

			// PEAR::Mail_Mime オブジェクト生成
			$mime = new Mail_Mime(MAIL_EOL);

			// PEAR::Mail オブジェクト生成
			$mail = Mail::factory("mail");

			$subject = '【メールフォームPHP】ログイン用パスワードを通知します';
			$body[] = 'メールフォームPHPをご利用いただきありがとうございます。';
			$body[] = '以下がログイン用パスワードになります。';
			$body[] = '';
			$body[] = $newpassword;
			$body[] = '';
			$body[] = '※ログイン用パスワードの変更は管理画面内で行えます。';
			$body = implode(MAIL_EOL,$body);
			$mime->setTxtBody(mb_convert_encoding($body,$iso2022jp,MAILFORMPHP_DEFAULT_ENCODE));
			$body = $mime->get($body_encode);

			// メールヘッダ情報を連想配列としてセット
			$headers = array(
				// To欄に入れるだけの物、実際に送信する先は$recipients
				"To" => null,
				// 送り元
				"From" => $from,
				// 日本語の件名を指定する場合、mb_encode_mimeheaderでエンコード
				"Subject" => mb_encode_mimeheader($subject)
			);

			$header = $mime->headers($headers);

			$result = $mail->send($from, $header, $body);
			if (PEAR::isError($result)) {
				$_html[] = '<p class="ui-state-error ui-corner-all">';
				$_html[] = $result;
				$_html[] = '</p>';
			} else {
				$_html[] = '<p style="margin:0 0 1em;">';
				$_html[] = '以下のメールアドレスにログイン用パスワードを送信しました。';
				$_html[] = '</p>';
				$_html[] = '<p>'.$_POST['mailaddress'].'</p>';
//				$_html[] = '<p>パスワード：'.htmlspecialchars($newpassword).'</p>';

				// #notdelivered
				$_html[] = '<p><a href="#notdelivered" class="button">しばらく待ってもメールが届かない場合は？</a></p>';
				$_html[] = '<div id="notdelivered" class="modal" title="しばらく待ってもメールが届かない場合は？">';
				$_html[] = '<p>以下の内容をご確認下さい。</p>';
				$_html[] = '<ol>';
				$_html[] = '<li>メールアドレスの入力が間違っていませんか？</li>';
				$_html[] = '<li>「迷惑メール」フォルダに配信されていませんか？</li>';
				$_html[] = '<li>現在お使いのWebサーバはメールが使用できる環境ですか？<br />ローカル等でテストを行なっている場合はご注意下さい。</li>';
				$_html[] = '</ol>';
				$_html[] = '</div>';

				// #aboutpassword
				$_html[] = '<p><a href="#aboutpassword" class="button">ログイン用パスワードについて</a></p>';
				$_html[] = '<div id="aboutpassword" class="modal" title="ログイン用パスワードについて">';
				$_html[] = '<ul>';
				$_html[] = '<li>ログイン用パスワードの再発行はできません。</li>';
				$_html[] = '<li>ログイン用パスワードの変更はログイン後のみ行えます。</li>';
				$_html[] = '<li>ログインできなくなった場合は、アカウントファイルを削除して<br />アカウントの作成をやり直して下さい。</li>';
				$_html[] = '</ul>';
				$_html[] = '</div>';

				// #accountfile
				$_html[] = '<p><a href="#accountfile" class="button">アカウントファイルはどこに保存されている？</a></p>';
				$_html[] = '<div id="accountfile" class="modal" title="アカウントファイルはどこに保存されている？">';
				$_html[] = '<p>以下のパスに保存されています。</p>';
				$_html[] = '<p>'.MAILFORMPHP_ACCOUNT.'</p>';
				$_html[] = '<p>このファイルを削除すると<br />アカウントの作成をやり直す事ができます。</p>';
				$_html[] = '<p>アカウントファイルを削除してもフォームの設定は削除されません。</p>';
				$_html[] = '</div>';

				$_html[] = '<br />';
				$_html[] = '<p><a href="'.$_SERVER['PHP_SELF'].'" class="go_login">ログインフォームへ</a></p>';
			}

		} else {
			$_html[] = '<p class="ui-state-error ui-corner-all">';
			$_html[] = 'アカウントファイルの生成に失敗しました。';
			$_html[] = '</p>';
		}

	}

	$html[] = renderHeader('Setup');
	$html[] = <<< SCRIPT_END
<script type="text/javascript">
jQuery(function(){
	$(':submit').button();
	$('a.button')
		.button({
			icons: {
				primary: "ui-icon-alert"
			}
		})
		.click(function(){
			$($(this).attr('href')).dialog('open');
			return false;
		});
	$('a.go_login')
		.button({
			icons: {
				primary: "ui-icon-key"
			}
		})

	$('.modal').dialog({
		autoOpen: false,
		modal: true,
		width: 'auto',
		resizable: false,
		buttons: {
			OK: function() {
				$( this ).dialog( "close" );
			}
		}
	});

})
</script>
SCRIPT_END;
	$html[] = <<< CSS_END
<style type="text/css">
html, body {
	font-family:'ヒラギノ角ゴ Pro W3','Hiragino Kaku Gothic Pro',osaka,'メイリオ',Meiryo,'ＭＳ Ｐゴシック',sans-serif;
	font-size: 13px;
	color: #333;
}
body {
	background: #f0f0f0;
}
input[type=text]{
	width: 250px;
	font-size: 13px;
	padding: 2px;
	border: 1px solid #999;
	background: #fff;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
	-o-border-radius: 3px;
	-ms-border-radius: 3px;

	-moz-box-shadow: inset 1px 1px 1px #999;
	-webkit-box-shadow: inset 1px 1px 1px #999;
	-o-box-shadow: inset 1px 1px 1px #999;
	-ms-box-shadow: inset 1px 1px 1px #999;

	position: relative;
	outline: 1;
}
input[type=submit] {
	-moz-box-shadow: 1px 1px 3px #999;
	-webkit-box-shadow: 1px 1px 3px #999;
	-o-box-shadow: 1px 1px 3px #999;
	-ms-box-shadow: 1px 1px 3px #999;
}
#setup_form {
	width: 400px;
	margin: 100px auto;
	padding: 15px;
	text-align: center;

	border: 1px solid #999;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	-o-border-radius: 5px;
	-ms-border-radius: 5px;

	-moz-box-shadow: 1px 1px 3px #999;
	-webkit-box-shadow: 1px 1px 3px #999;
	-o-box-shadow: 1px 1px 3px #999;
	-ms-box-shadow: 1px 1px 3px #999;

	background: #fff;
}
.tleft {
	text-align: left;
}
.icon-left {
	float: left;
	margin-right: 0;
}
.modal {
	display: none;
}
</style>
CSS_END;
	$html[] = '<div id="setup_form" class="ui-corner-all">';
if (!$valid_mailaddress) {
	$html[] = <<< FORM_END
<form method="post" action="$_SERVER[PHP_SELF]">
<input type="hidden" name="setup" value="1" />
<p style="margin:0 0 1em;">
入力されたメールアドレスにログイン用パスワードを送信します。<br />
</p>
<p>メールアドレス：<input type="text" name="mailaddress"></p>
<p><input type="submit" value="アカウント作成"></p>
</form>
FORM_END;
}
	if ($_html) {
		$html[] = implode("\n",$_html);
	}
	if ($msg) {
		$html[] = '<p class="ui-state-error ui-corner-all">'.$msg.'</p>';
	}

	$html[] = 'Powered by <a href="http://kantaro-cgi.com/" target="_blank" title="デザインカスタム自由CGI「カンタローCGI」">カンタローCGI</a>';
	$html[] = '</div>';
	$html[] = '</body></html>';
	echo implode("\n",$html);
}

function makeAccount($username,$password){
	$php[] = '<?php';
	$php[] = '/* ';
	$php[] = ' * ユーザーアカウント';
	$php[] = ' * 作成日時：' . date('Y.m.d H:i',UNIX_TIME);
	$php[] = ' * IP:' . $_SERVER['REMOTE_ADDR'];
	$php[] = ' * UA:' . $_SERVER['HTTP_USER_AGENT'];
	$php[] = ' */';
	$php[] = '$user = array(';
	$php[] = "\t".addArraysValue($username,md5($password));
	$php[] = ');';
	return makefile(MAILFORMPHP_ACCOUNT, implode("\n",$php));
}

function loginFunction($username = null, $status = null, &$auth){
	switch ($status) {
		case AUTH_IDLED:
		case AUTH_EXPIRED:
			$msg = "認証期限が切れました。<br />再ログインして下さい。";
			break;
		case AUTH_WRONG_LOGIN:
			$msg = "メールアドレス / パスワード が間違ってます。";
			break;
		default:
			break;
	}
	$html[] = renderHeader('ログイン');
	$html[] = <<< SCRIPT_END
<script type="text/javascript">
jQuery(function(){
	$(':submit').button();
})
</script>
SCRIPT_END;
	$html[] = <<< CSS_END
<style type="text/css">
html, body {
	font-family:'ヒラギノ角ゴ Pro W3','Hiragino Kaku Gothic Pro',osaka,'メイリオ',Meiryo,'ＭＳ Ｐゴシック',sans-serif;
	font-size: 13px;
	color: #333;
}
body {
	background: #f0f0f0;
}
input[type=text], input[type=password]{
	width: 250px;
	font-size: 13px;
	padding: 2px;
	border: 1px solid #999;
	background: #fff;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
	-o-border-radius: 3px;
	-ms-border-radius: 3px;

	-moz-box-shadow: inset 1px 1px 1px #999;
	-webkit-box-shadow: inset 1px 1px 1px #999;
	-o-box-shadow: inset 1px 1px 1px #999;
	-ms-box-shadow: inset 1px 1px 1px #999;

	position: relative;
	outline: 1;
}
input[type=submit] {
	-moz-box-shadow: 1px 1px 3px #999;
	-webkit-box-shadow: 1px 1px 3px #999;
	-o-box-shadow: 1px 1px 3px #999;
	-ms-box-shadow: 1px 1px 3px #999;
}
#login_form {
	width: 400px;
	margin: 100px auto;
	padding: 15px;
	text-align: center;

	border: 1px solid #999;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	-o-border-radius: 5px;
	-ms-border-radius: 5px;

	-moz-box-shadow: 1px 1px 3px #999;
	-webkit-box-shadow: 1px 1px 3px #999;
	-o-box-shadow: 1px 1px 3px #999;
	-ms-box-shadow: 1px 1px 3px #999;

	background: #fff;
}
</style>
CSS_END;

	$html[] = <<< FORM_END
<div id="login_form" class="ui-corner-all">
<form method="post" action="$_SERVER[PHP_SELF]">
<p>メールアドレス：<input type="text" name="username"></p>
<p>パスワード　　：<input type="password" name="password"></p>
<p><input type="submit" value="認証する"></p>
</form>
FORM_END;
	if ($msg) {
		$html[] = '<p class="ui-state-error ui-corner-all">'.$msg.'</p>';
	}
	$html[] = 'Powered by <a href="http://kantaro-cgi.com/" target="_blank" title="カンタローCGI">カンタローCGI</a>';
	$html[] = '</div>';
	$html[] = '</body></html>';
	echo implode("\n",$html);
}


# ====================================================================
# このプログラムソースの著作/所有はカザオキラボに帰属します。
# 無断で複製/改造/修正/公開等の著作を侵害する恐れのある行為、及びこの
# 表記の変更/削除を一切禁じます。また、当方で使用許可していないプログ
# ラムからの利用/呼び出しも硬く禁じます。
# --------------------------------------------------------------------
#                                カンタローCGI http://kantaro-cgi.com/
#                                      カザオキラボ http://kazaoki.jp/
# ====================================================================

1;
